@@ -5,26 +5,28 @@ module Kz
 
   class << self
     def reload(kz)
-      if ENABLE
-        $LOAD_PATH.clear
-        $LOAD_PATH.concat(DEFAULT_LOAD_PATH)
-        kz.ext_reload
+      barrier do
+        if ENABLE
+          $LOAD_PATH.clear
+          $LOAD_PATH.concat(DEFAULT_LOAD_PATH)
+          kz.ext_reload
+        end
       end
-    rescue Exception
-      print_error($!)
     end
 
-    def pop_statusbar(kz, id, timeout)
+    def pop_statusbar(kz, id_or_name, timeout)
       Gtk.timeout_add(timeout) do
-        kz.statusbar.pop(id)
-        false
+        barrier do
+          kz.statusbar.set_text(nil, id_or_name)
+          false
+        end
       end
     end
 
     def setup(kz)
-      kz.ext_setup
-    rescue Exception
-      print_error($!)
+      barrier do
+        kz.ext_setup
+      end
     end
   end
 
@@ -39,4 +41,7 @@ module Kz
   end
 end
 
+require "kz/gettext"
+require "kz/utils"
 require "kz/actions"
+require "kz/sidebar"
