@@ -28,6 +28,7 @@
 #define RVAL2KZNAVI(obj) (KZ_NAVI(RVAL2GOBJ(obj)))
 #define RVAL2KZNAVLINK(obj) (RVAL2GENUM(obj, KZ_TYPE_EMBED_NAV_LINK))
 #define RVAL2KZRF(obj) (RVAL2GENUM(obj, KZ_TYPE_EMBED_RELOAD_FLAG))
+#define RVAL2KZCT(obj) (RVAL2GENUM(obj, KZ_TYPE_EMBED_COPY_TYPE))
 
 static VALUE
 rb_kz_embed_get_window(VALUE self)
@@ -230,9 +231,9 @@ rb_kz_embed_get_dest_anchors(VALUE self)
 }
 
 static VALUE
-rb_kz_embed_copy_page(VALUE self, VALUE dkzembed)
+rb_kz_embed_copy_page(VALUE self, VALUE dkzembed, VALUE type)
 {
-    kz_embed_copy_page(_SELF(self), _SELF(dkzembed));
+    kz_embed_copy_page(_SELF(self), _SELF(dkzembed), RVAL2KZCT(type));
     return self;
 }
 
@@ -631,6 +632,7 @@ Init_kz_rb_embed(VALUE mKz)
     G_DEF_CLASS(KZ_TYPE_EMBED_RELOAD_FLAG, "EmbedReloadFlag", mKz);
     G_DEF_CLASS(KZ_TYPE_EMBED_GO_ACTION, "EmbedGoAction", mKz);
     G_DEF_CLASS(KZ_TYPE_EMBED_NAV_LINK, "EmbedNavLink", mKz);
+    G_DEF_CLASS(KZ_TYPE_EMBED_COPY_TYPE, "EmbedCopyType", mKz);
 
     rb_define_method(cKzEmbed, "window", rb_kz_embed_get_window, 0);
 
