@@ -443,7 +443,7 @@ GtkActionEntry kz_actions_popup[] =
 	{"OpenThisFrame",        NULL, N_("Open this _frame"),
 	NULL, N_("Open the frame in the current tab"),  G_CALLBACK(act_popup_open_frame)},
 
-	{"LaunchEditor",         KZ_STOCK_EDITOR, N_("_Launch Editor"),
+	{"LaunchEditor",         GTK_STOCK_EDIT, N_("_Launch Editor"),
 	 NULL, N_("Launch external editor"), G_CALLBACK(act_popup_launch_editor)},
 	{"PopupTabList",         NULL, N_("_Popup TabList"),
 	 NULL, N_("Display tab list"), G_CALLBACK(act_popup_tab_list)},
