@@ -37,8 +37,7 @@ G_BEGIN_DECLS
 extern GtkActionEntry      kz_actions_popup[];
 extern const gint          kz_actions_popup_len;
 
-GtkActionGroup *kz_actions_popup_create_group (KzWindow      *kz,
-					       GtkAccelGroup *accel_group);
+GtkActionGroup *kz_actions_popup_create_group (KzWindow      *kz);
 
 void            kz_actions_popup_menu_modal   (KzWindow      *kz,
 					       guint          button,
