@@ -28,6 +28,7 @@
 #include <sys/stat.h>
 #include <unistd.h>
 #include <glib/gi18n.h>
+#include <glib/gstdio.h>
 
 #include "kazehakase.h"
 #include "utils/utils.h"
@@ -412,7 +413,8 @@ kz_location_entry_action_restore_history (KzLocationEntryAction *action)
 		const gchar *key = node->data;
 		gchar *value;
 
-		if (!key_seems_sequential(key, "history")) continue;
+		if (!(key && *key) || !key_seems_sequential(key, "history"))
+			continue;
 
 		value = KZ_CONF_GET_STR("LocationEntry", key);
 		if (value && *value)
@@ -444,7 +446,7 @@ kz_location_entry_action_restore_history (KzLocationEntryAction *action)
 static void
 kz_location_entry_action_sync_history (KzLocationEntryAction *action)
 {
-	GList *list, *node;
+	const GList *list, *node;
 
 	g_return_if_fail(KZ_IS_LOCATION_ENTRY_ACTION(action));
 
@@ -532,7 +534,7 @@ is_dir(const gchar *path)
 	gboolean result = FALSE;
 	struct stat buf;
 
-	if (stat(path, &buf) == 0)
+	if (g_stat(path, &buf) == 0)
 	{
 		result = S_ISDIR(buf.st_mode);
 	}
@@ -559,7 +561,7 @@ collect_file_path(GDir *dir, const gchar *prefix, gchar *dir_name,
 	     name = g_dir_read_name(dir))
 	{
 		if (!is_dir_path &&
-		    strncmp(base_name, name, strlen(base_name)) != 0)
+		    !g_str_has_prefix(name, base_name))
 			continue;
 				
 		full_path = g_build_filename(dir_name, name, NULL);
@@ -613,8 +615,8 @@ kz_location_entry_action_add_file_path_to_history(KzLocationEntryAction *action,
 
 		g_dir_close(dir);
 		
-		g_list_concat(list,
-			      kz_history_action_get_history(KZ_HISTORY_ACTION(action)));
+		list = g_list_concat(list,
+				     kz_history_action_get_history(KZ_HISTORY_ACTION(action)));
 		kz_history_action_set_history(KZ_HISTORY_ACTION(action), list);
 
 		g_list_foreach(list, (GFunc)g_free, NULL);
