@@ -18,7 +18,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-bookmark-edit.c,v 1.34 2005/02/14 05:45:04 ikezoe Exp $
+ *  $Id: kz-bookmark-edit.c,v 1.35 2005/04/28 13:40:55 ikezoe Exp $
  */
 
 #include <glib/gi18n.h>
@@ -746,7 +746,7 @@ cb_smart_down_button (GtkButton *button, KzBookmarkEdit *edit)
 
 	gtk_list_store_swap(store, &iter, &next);
 	kz_bookmark_edit_update_smart_list(edit);
-	gtk_tree_selection_select_iter(selection, &next);
+	//gtk_tree_selection_select_iter(selection, &next);
 }
 
 
