@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-bookmark-editor.c,v 1.41 2005/05/09 01:20:12 ikezoe Exp $
+ *  $Id: kz-bookmark-editor.c,v 1.42 2006/06/02 02:23:41 ikezoe Exp $
  */
 
 #include "kz-bookmark-editor.h"
@@ -734,7 +734,7 @@ cb_bookmarks_view_button_press (GtkWidget *widget, GdkEventButton *event,
 	kz = gtk_window_get_transient_for(GTK_WINDOW(editor));
 	if (!KZ_IS_WINDOW(kz))
 	{
-		GList *list = kz_window_get_window_list();
+		const GList *list = kz_window_get_window_list();
 		if (list)
 			kz = list->data;
 		else
