@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-bookmark-editor.h,v 1.12 2004/11/25 07:28:47 ikezoe Exp $
+ *  $Id: kz-bookmark-editor.h,v 1.13 2005/05/09 01:20:12 ikezoe Exp $
  */
 
 #ifndef __KZ_BOOKMARK_EDITOR_H__
@@ -38,7 +38,6 @@ G_BEGIN_DECLS
 
 typedef struct _KzBookmarkEditor	KzBookmarkEditor;
 typedef struct _KzBookmarkEditorClass	KzBookmarkEditorClass;
-typedef struct _KzBookmarkEditorPriv	KzBookmarkEditorPriv;
 
 struct _KzBookmarkEditor
 {
@@ -58,8 +57,6 @@ struct _KzBookmarkEditor
 	/* other objects */
 	GtkActionGroup *action_group;
 	GtkUIManager   *menu_merge;
-
-	KzBookmarkEditorPriv *priv;
 };
 
 struct _KzBookmarkEditorClass
