@@ -18,7 +18,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-bookmark-file.h,v 1.7 2005/04/07 05:41:50 ikezoe Exp $
+ *  $Id: kz-bookmark-file.h,v 1.8 2005/07/12 01:55:11 ikezoe Exp $
  */
 
 #ifndef __KZ_BOOKMARK_FILE_H__
@@ -148,7 +148,7 @@ void		kz_bookmark_file_xmlrpc_move     (KzBookmarkFile *file,
 						  KzBookmark *folder,
 						  KzBookmark *sibling,
 						  KzBookmark *child);
-gboolean	kz_bookmark_file_is_updated	 (KzBookmarkFile *bookmark_file);
+gboolean	kz_bookmark_file_is_update	 (KzBookmarkFile *bookmark_file);
 
 G_END_DECLS
 
