@@ -18,7 +18,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-bookmark-item.c,v 1.20 2005/07/21 14:43:28 ikezoe Exp $
+ *  $Id: kz-bookmark-item.c,v 1.21 2006/08/06 15:55:49 furyo Exp $
  */
 
 #include "kz-bookmark-item.h"
@@ -730,7 +730,7 @@ cb_drag_data_received (GtkWidget        *widget,
 		if (utf8_title && g_utf8_validate(utf8_title, -1, NULL))
 			title = utf8_title;
 		else 
-			title = _("title");
+			title = _("Title");
 		
 		/* FIXME! we should also add normal bookmark. */
 		/* Create New KzBookmark */
