@@ -18,7 +18,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-bookmark-menu-item.c,v 1.7 2005/07/21 14:43:28 ikezoe Exp $
+ *  $Id: kz-bookmark-menu-item.c,v 1.8 2006/02/16 14:47:32 furyo Exp $
  */
 
 #include "kz-bookmark-menu-item.h"
@@ -187,6 +187,7 @@ kz_bookmark_menu_item_button_release (GtkWidget *widget, GdkEventButton *event)
 	gint button = event->button;
 	KzBookmarkBaseMenuItem *parent;
 	KzBookmarkMenuItem *item;;
+	GtkAction *action;
 
 	parent = KZ_BOOKMARK_BASE_MENU_ITEM(widget);
 	item = KZ_BOOKMARK_MENU_ITEM(widget);
@@ -197,7 +198,19 @@ kz_bookmark_menu_item_button_release (GtkWidget *widget, GdkEventButton *event)
 	{
 	case 2:
 		if (uri)
+		{
 			kz_window_open_new_tab(parent->kz, uri);
+		}
+		else if(kz_bookmark_is_folder(parent->bookmark))
+		{
+
+			kz_actions_set_bookmark_for_action(parent->kz, parent->bookmark);
+			action = gtk_action_group_get_action(parent->kz->actions,
+							     "OpenAllBookmarks");
+			if (action)
+				gtk_action_activate(action);
+			kz_actions_set_bookmark_for_action(parent->kz, NULL);
+		}
 
 		KZ_CONF_GET("Global", "keep_bookmark_menu", keep, BOOL);
 		if (!keep)
