@@ -18,7 +18,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-bookmark-menu.h,v 1.1 2004/09/30 04:32:11 makeinu Exp $
+ *  $Id: kz-bookmark-menu.h,v 1.2 2005/07/20 03:53:17 ikezoe Exp $
  */
 
 #ifndef __KZ_BOOKMARK_MENU_H__
@@ -31,9 +31,6 @@
 
 G_BEGIN_DECLS
 
-GtkWidget *kz_bookmark_menu_create_menuitem  (KzBookmark *bookmark,
-					      KzWindow   *kz,
-					      gboolean    is_folder_proxy);
 GtkWidget *kz_bookmark_menu_create_submenu   (KzBookmark *folder,
 					      KzWindow   *kz);
 
