@@ -18,7 +18,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-bookmark-tab-menu.c,v 1.7 2005/07/14 03:06:21 ikezoe Exp $
+ *  $Id: kz-bookmark-tab-menu.c,v 1.8 2006/06/02 02:23:27 ikezoe Exp $
  */
 
 #include "kz-bookmark-tab-menu.h"
@@ -475,7 +475,7 @@ disconnect_menu_signals (KzBookmark *folder, GtkMenuShell *shell)
 static void 
 cb_tab_menu_item_activate (GtkWidget *widget, KzWindow *kz)
 {
-	KzBookmark *item, *parent;
+	KzBookmark *item;
 	GtkWidget *kzembed;
 	KzTabLabel *kztab;
 
