@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-bookmarks-view.c,v 1.28 2005/07/21 05:02:01 ikezoe Exp $
+ *  $Id: kz-bookmarks-view.c,v 1.31 2005/09/11 01:02:43 kous Exp $
  */
 
 #include "kz-bookmarks-view.h"
@@ -1076,12 +1076,13 @@ cb_drag_data_received (GtkWidget *widget,
 	GtkWidget *src_widget;
 	KzBookmark *src, *dest, *parent;
 	KzBookmark *file;
+	gboolean success = FALSE;
 
 	/* get dest bookmark */
 	gtk_tree_view_get_dest_row_at_pos(GTK_TREE_VIEW(widget),
 					  x, y,
 					  &dest_path, &pos);
-	if (!dest_path) return;
+	if (!dest_path) goto ERROR;
 	gtk_tree_model_get_iter(model, &dest_iter, dest_path);
 	gtk_tree_model_get(model, &dest_iter,
 			   COLUMN_BOOKMARK, &dest,
@@ -1107,6 +1108,7 @@ cb_drag_data_received (GtkWidget *widget,
 				   TERMINATOR);
 	}
 	if (!src_path || !src) goto ERROR;
+	if (gtk_tree_path_is_ancestor(src_path, dest_path)) goto ERROR;
 	if (src == dest) goto ERROR;
 
 	/* move the bookmark(s?) */
@@ -1175,13 +1177,16 @@ cb_drag_data_received (GtkWidget *widget,
 						       src);
 		}
 		g_object_unref(src);
-		gtk_drag_finish(context, TRUE, FALSE, time);
+		success = TRUE;
 		break;
 	default:
 		break;
 	}
 
-	gtk_tree_path_free(src_path);
 ERROR:
-	gtk_tree_path_free(dest_path);
+	gtk_drag_finish(context, success, FALSE, time);
+	if (src_path)
+		gtk_tree_path_free(src_path);
+	if (dest_path)
+		gtk_tree_path_free(dest_path);
 }
