@@ -61,7 +61,7 @@ static gboolean
 kz_nsbookmark_is_supported(KzBookmarkFile *bookmark, const gchar *buf)
 {
 	g_return_val_if_fail(buf, FALSE);
-	if (!strncmp(buf, "<!DOCTYPE NETSCAPE-Bookmark", 27))
+	if (g_str_has_prefix(buf, "<!DOCTYPE NETSCAPE-Bookmark"))
 		return TRUE;
 
 	return FALSE;
