@@ -71,7 +71,7 @@ kz_rss_is_supported(KzBookmarkFile *bookmark, const gchar *buf)
 
 	g_return_val_if_fail(buf, FALSE);
 
-	if (strncmp(buf, "<?xml", 5)) return FALSE;
+	if (!g_str_has_prefix(buf, "<?xml")) return FALSE;
 
 	pos = buf;
 
@@ -82,7 +82,7 @@ kz_rss_is_supported(KzBookmarkFile *bookmark, const gchar *buf)
 
 	if (!pos) return FALSE;
 
-	if (!strncmp(pos, "<rdf",4) || !strncmp(pos, "<rss",4))
+	if (g_str_has_prefix(pos, "<rdf") || g_str_has_prefix(pos, "<rss"))
 		return TRUE;
 
 	return FALSE;
