@@ -18,7 +18,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-smart-bookmark.c,v 1.2 2004/11/22 01:08:41 ikezoe Exp $
+ *  $Id: kz-smart-bookmark.c,v 1.4 2005/07/11 03:05:50 ikezoe Exp $
  */
 
 #include "kz-smart-bookmark.h"
@@ -29,23 +29,33 @@
 #include "gobject-utils.h"
 #include "eggregex.h"
 #include "utils.h"
+#include "kz-bookmark-file.h"
+
+typedef struct _KzSmartBookmarkPrivate	KzSmartBookmarkPrivate;
+struct _KzSmartBookmarkPrivate
+{
+	KzBookmark *history;
+};
+
+#define KZ_SMART_BOOKMARK_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), KZ_TYPE_SMART_BOOKMARK, KzSmartBookmarkPrivate))
 
 enum {
 	PROP_0,
-	PROP_SMART_LIST
+	PROP_SMART_LIST,
+	PROP_SMART_HISTORY
 };
 
 static void     kz_smart_bookmark_class_init  (KzSmartBookmarkClass *klass);
 static void     kz_smart_bookmark_init        (KzSmartBookmark *bookmark);
 static void     kz_smart_bookmark_dispose     (GObject *object);
-static void kz_smart_bookmark_set_property (GObject         *object,
-				      guint            prop_id,
-				      const GValue    *value,
-				      GParamSpec      *pspec);
-static void kz_smart_bookmark_get_property (GObject         *object,
-				      guint            prop_id,
-				      GValue          *value,
-				      GParamSpec      *pspec);
+static void     kz_smart_bookmark_set_property (GObject         *object,
+				                guint            prop_id,
+				                const GValue    *value,
+				                GParamSpec      *pspec);
+static void     kz_smart_bookmark_get_property (GObject         *object,
+				                guint            prop_id,
+				                GValue          *value,
+				                GParamSpec      *pspec);
 
 
 static KzBookmarkClass *parent_class;
@@ -78,13 +88,28 @@ kz_smart_bookmark_class_init (KzSmartBookmarkClass *klass)
 			 _("The List for the Smart Bookmark"),
 			 G_PARAM_READWRITE));
 
+	g_object_class_install_property(
+		object_class,
+		 PROP_SMART_HISTORY,
+		 g_param_spec_object(
+			 "smart-history",
+			 _("History bookmark for smart bookmark"),
+			 _("The history bookmark for the Smart Bookmark"),
+			 KZ_TYPE_BOOKMARK,
+			 G_PARAM_READWRITE));
+
 	smart_list_quark  = g_quark_from_string("KzBookmark::SmartBookmarkList");
+
+	g_type_class_add_private (object_class, sizeof(KzSmartBookmarkPrivate));
 }
 
 
 static void
 kz_smart_bookmark_init (KzSmartBookmark *smart)
 {
+	KzSmartBookmarkPrivate *priv = KZ_SMART_BOOKMARK_GET_PRIVATE (smart);
+
+	priv->history = NULL;
 }
 
 
@@ -115,18 +140,20 @@ free_smart_list (GList *list)
 static void
 kz_smart_bookmark_dispose (GObject *object)
 {
-	KzSmartBookmark *smart;
+	KzSmartBookmark *smart = KZ_SMART_BOOKMARK(object);
 	GList *smart_list;
-
-	g_return_if_fail(KZ_IS_SMART_BOOKMARK(object));
-
-	smart = KZ_SMART_BOOKMARK(object);
+	KzSmartBookmarkPrivate *priv = KZ_SMART_BOOKMARK_GET_PRIVATE (smart);
 
 	/* smart property */
 	smart_list = g_object_get_qdata(object, smart_list_quark);
 	free_smart_list(smart_list);
 	g_object_set_qdata(object, smart_list_quark, NULL);
 
+	if (priv->history)
+		g_object_unref (priv->history);
+
+	priv->history = NULL;
+
 	if (G_OBJECT_CLASS (parent_class)->dispose)
 		G_OBJECT_CLASS (parent_class)->dispose(object);
 }
@@ -134,15 +161,21 @@ kz_smart_bookmark_dispose (GObject *object)
 
 static void
 kz_smart_bookmark_set_property (GObject *object,
-			  guint prop_id,
-			  const GValue *value,
-			  GParamSpec *pspec)
+			        guint prop_id,
+			        const GValue *value,
+			        GParamSpec *pspec)
 {
-	switch (prop_id) {
+	KzSmartBookmarkPrivate *priv = KZ_SMART_BOOKMARK_GET_PRIVATE (object);
+
+	switch (prop_id)
+       	{
 	case PROP_SMART_LIST:
 		g_object_set_qdata(object, smart_list_quark, 
 				   g_value_get_pointer(value));
 		break;
+	case PROP_SMART_HISTORY:
+		priv->history = g_object_ref(g_value_get_object(value));
+		break;
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
 		break;
@@ -152,15 +185,21 @@ kz_smart_bookmark_set_property (GObject *object,
 
 static void
 kz_smart_bookmark_get_property (GObject *object,
-		     guint prop_id,
-		     GValue *value,
-		     GParamSpec *pspec)
+		                guint prop_id,
+		                GValue *value,
+		                GParamSpec *pspec)
 {
-	switch (prop_id) {
+	KzSmartBookmarkPrivate *priv = KZ_SMART_BOOKMARK_GET_PRIVATE (object);
+
+	switch (prop_id)
+       	{
 	case PROP_SMART_LIST:
 		g_value_set_pointer(value, 
 				    g_object_get_qdata(object, smart_list_quark));
 		break;
+	case PROP_SMART_HISTORY:
+		g_value_set_object(value, priv->history);
+		break;
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
 		break;
@@ -361,3 +400,25 @@ kz_smart_bookmark_get_smart_list (KzSmartBookmark *bookmark)
 	return list;
 }
 
+KzBookmark *
+kz_smart_bookmark_get_history (KzSmartBookmark *bookmark)
+{
+	KzSmartBookmarkPrivate *priv;
+
+	g_return_val_if_fail(KZ_IS_SMART_BOOKMARK(bookmark), NULL);
+	
+	priv = KZ_SMART_BOOKMARK_GET_PRIVATE (bookmark);
+
+	return priv->history;
+}
+
+void 
+kz_smart_bookmark_set_history (KzSmartBookmark *bookmark, 
+			       KzBookmark *history)
+{
+	g_return_if_fail(KZ_IS_SMART_BOOKMARK(bookmark));
+	g_return_if_fail(KZ_IS_BOOKMARK(history));
+	
+	g_object_set(G_OBJECT(bookmark), "smart-history", history, NULL);
+}
+
