@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-xbel.c,v 1.66 2005/09/23 12:44:56 tyuyu Exp $
+ *  $Id: kz-xbel.c,v 1.68 2006/01/06 02:58:42 makeinu Exp $
  */
 
 #include "kazehakase.h"
@@ -103,7 +103,7 @@ kz_xbel_is_supported(KzBookmarkFile *bookmark, const gchar *buf)
 
 	g_return_val_if_fail(buf, FALSE);
 
-	if (strncmp(buf, "<?xml", 5)) return FALSE;
+	if (!g_str_has_prefix(buf, "<?xml")) return FALSE;
 
 	pos = buf;
 
@@ -112,7 +112,7 @@ kz_xbel_is_supported(KzBookmarkFile *bookmark, const gchar *buf)
 		pos = strchr(pos + 1, '<');
 	while (pos && pos[1] == '!');
 
-	if (pos && !strncmp(pos, "<xbel", 5))
+	if (pos && g_str_has_prefix(pos, "<xbel"))
 		return TRUE;
 
 	return FALSE;
@@ -325,73 +325,73 @@ parse_metadata_node (KzBookmark *bookmark, KzXMLNode *parent)
 		{
 			KzXMLAttr *attr = a_node->data;
 
-			if (!strncmp(attr->name, "kz:update_interval", 118))
+			if (g_str_has_prefix(attr->name, "kz:update_interval"))
 			{
 				interval = atoi(attr->value);
 				kz_bookmark_file_set_interval(KZ_BOOKMARK_FILE(bookmark), interval);
 			}
-			else if (!strncmp(attr->name, "kz:smart_regex", 14))
+			else if (g_str_has_prefix(attr->name, "kz:smart_regex"))
 			{
 				smart_regex = attr->value;
 			}
-			else if (!strncmp(attr->name, "kz:smart_uri", 12))
+			else if (g_str_has_prefix(attr->name, "kz:smart_uri"))
 			{
 				smart_uri = attr->value;
 			}
-			else if (!strncmp(attr->name, "kz:smart_encode", 15))
+			else if (g_str_has_prefix(attr->name, "kz:smart_encode"))
 			{
 				smart_encode = attr->value;
 			}
-			else if (!strncmp(attr->name, "kz:smart_urlencode", 18))
+			else if (g_str_has_prefix(attr->name, "kz:smart_urlencode"))
 			{
 				urlencode = TRUE;
 			}
-			else if (!strncmp(attr->name, "kz:smart_history", 16) && !smart_history)
+			else if (g_str_has_prefix(attr->name, "kz:smart_history") && !smart_history)
 			{
 				smart_history = KZ_BOOKMARK(kz_bookmark_file_new(attr->value,
 							    NULL, NULL));
 				is_smart_history = TRUE;
 			}
-			else if (!strncmp(attr->name, "kz:xmlrpc", 9))
+			else if (g_str_has_prefix(attr->name, "kz:xmlrpc"))
 			{
 				kz_bookmark_file_set_xmlrpc(KZ_BOOKMARK_FILE(bookmark), attr->value);
 			}
-			else if (!strncmp(attr->name, "kz:xmlrpc_user", 14))
+			else if (g_str_has_prefix(attr->name, "kz:xmlrpc_user"))
 			{
 				kz_bookmark_file_set_xmlrpc_user(KZ_BOOKMARK_FILE(bookmark), attr->value);
 			}
-			else if (!strncmp(attr->name, "kz:xmlrpc_pass", 14))
+			else if (g_str_has_prefix(attr->name, "kz:xmlrpc_pass"))
 			{
 				kz_bookmark_file_set_xmlrpc_pass(KZ_BOOKMARK_FILE(bookmark), attr->value);
 			}
-			else if (!strncmp(attr->name, "kz:smart_xmlrpc", 9))
+			else if (g_str_has_prefix(attr->name, "kz:smart_xmlrpc"))
 			{
 				kz_bookmark_file_set_xmlrpc(KZ_BOOKMARK_FILE(smart_history), attr->value);
 			}
-			else if (!strncmp(attr->name, "kz:smart_xmlrpc_user", 14))
+			else if (g_str_has_prefix(attr->name, "kz:smart_xmlrpc_user"))
 			{
 				kz_bookmark_file_set_xmlrpc_user(KZ_BOOKMARK_FILE(smart_history), attr->value);
 			}
-			else if (!strncmp(attr->name, "kz:smart_xmlrpc_pass", 14))
+			else if (g_str_has_prefix(attr->name, "kz:smart_xmlrpc_pass"))
 			{
 				kz_bookmark_file_set_xmlrpc_pass(KZ_BOOKMARK_FILE(smart_history), attr->value);
 			}
-			else if (!strncmp(attr->name, "kz:current_position", 18))
+			else if (g_str_has_prefix(attr->name, "kz:current_position"))
 			{
-				gint pos = atoi(attr->value);
+				guint pos = (guint)atoi(attr->value);
 				kz_bookmark_set_current(bookmark, pos);
 			}
-			else if (!strncmp(attr->name, "kz:lock", 7))
+			else if (g_str_has_prefix(attr->name, "kz:lock"))
 			{
 				if (!strcmp(attr->value, "yes"))
 					kz_bookmark_set_lock(bookmark, TRUE);
 			}
-			else if (!strncmp(attr->name, "kz:auto_refresh", 15))
+			else if (g_str_has_prefix(attr->name, "kz:auto_refresh"))
 			{
 				if (!strcmp(attr->value, "yes"))
 					kz_bookmark_set_auto_refresh(bookmark, TRUE);
 			}
-			else if (!strncmp(attr->name, "kz:javascript", 13))
+			else if (g_str_has_prefix(attr->name, "kz:javascript"))
 			{
 				if (!strcmp(attr->value, "yes"))
 					kz_bookmark_set_javascript(bookmark, TRUE);
@@ -472,7 +472,7 @@ xml_node_has_smart_property (KzXMLNode *parent)
 		{
 			KzXMLAttr *attr = list->data;
 
-			if (!strncmp(attr->name, "kz:smart", 7))
+			if (g_str_has_prefix(attr->name, "kz:smart"))
 			{
 				ret = TRUE;
 				break;
