@@ -75,6 +75,20 @@ KZ_OBJECT_GET_TYPE(kz_print_dialog, "KzPrintDialog", KzPrintDialog,
 		   kz_print_dialog_class_init, kz_print_dialog_init,
 		   GTK_TYPE_DIALOG)
 
+static void
+free_print_info (KzPrintDialog *print)
+{
+	if (print->info)
+	{
+		if (print->info->printer)
+			g_free(print->info->printer);
+		print->info->printer = NULL;
+
+		g_free(print->info);
+		print->info = NULL;
+	}
+}
+
 static void
 kz_print_dialog_class_init (KzPrintDialogClass *klass)
 {
@@ -307,16 +321,8 @@ kz_print_dialog_dispose (GObject *object)
 		print->kz = NULL;
 	}
 
-	if (print->info)
-	{
-		if (print->info->printer)
-			g_free(print->info->printer);
-		print->info->printer = NULL;
+	free_print_info (print);
 
-		g_free(print->info);
-		print->info = NULL;
-	}
-	
 	if (G_OBJECT_CLASS (parent_class)->dispose)
 		G_OBJECT_CLASS (parent_class)->dispose(object);
 }
@@ -482,6 +488,8 @@ kz_print_dialog_get_print_info (KzPrintDialog *print)
 	info->to_page   = gtk_spin_button_get_value_as_int(
 				GTK_SPIN_BUTTON(priv->to_page));
 
+	free_print_info (print);
+
 	print->info = info;
 
 	return info;
