@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-khtml.h,v 1.2 2004/11/25 07:28:48 ikezoe Exp $
+ *  $Id: kz-khtml.h,v 1.3 2005/05/09 01:20:12 ikezoe Exp $
  */
 
 #ifndef __KZ_KHTML_H__
@@ -40,7 +40,6 @@ G_BEGIN_DECLS
 
 typedef struct _KzKHTML		KzKHTML;
 typedef struct _KzKHTMLClass	KzKHTMLClass;
-typedef struct _KzKHTMLPriv	KzKHTMLPriv;
 
 struct _KzKHTML
 {
@@ -48,8 +47,6 @@ struct _KzKHTML
 	GtkKHTML parent;
 
 	gboolean  is_loading;
-
-	KzKHTMLPriv *priv;
 };
 
 struct _KzKHTMLClass
