@@ -246,7 +246,7 @@ kz_download_box_drag_data_received (GtkWidget *widget,
 	 case TARGET_TEXT_URI_LIST:
 		if (data->length < 0) return;
 
-		strings = g_strsplit(data->data, "\n", 2);
+		strings = g_strsplit((const gchar*)data->data, "\n", 2);
 
 		basename = g_path_get_basename(strings[0]);
 		if (g_file_test(basename, G_FILE_TEST_EXISTS))
