@@ -66,7 +66,9 @@ KzDownloader *kz_downloader_new_with_filename (const gchar *uri, const gchar *fi
 
 void          kz_downloader_cancel               (KzDownloader *downloader);
 gboolean      kz_downloader_to_file              (KzDownloader *downloader);
+gboolean      kz_downloader_to_buffer            (KzDownloader *downloader);
 const gchar  *kz_downloader_get_string           (KzDownloader *downloader);
+gsize         kz_downloader_get_size             (KzDownloader *downloader);
 gint          kz_downloader_get_percent          (KzDownloader *downloader);
 gsize         kz_downloader_get_current_progress (KzDownloader *downloader);
 gsize         kz_downloader_get_total_progress   (KzDownloader *downloader);
