@@ -494,12 +494,12 @@ kz_embed_get_dest_anchors (KzEmbed *kzembed,
 
 
 void
-kz_embed_copy_page (KzEmbed *kzembed, KzEmbed *dkzembed)
+kz_embed_copy_page (KzEmbed *kzembed, KzEmbed *dkzembed, KzEmbedCopyType type)
 {
 	g_return_if_fail(KZ_IS_EMBED(kzembed));
 	g_return_if_fail(KZ_EMBED_GET_IFACE(kzembed)->copy_page);
 
-	KZ_EMBED_GET_IFACE(kzembed)->copy_page(kzembed, dkzembed);
+	KZ_EMBED_GET_IFACE(kzembed)->copy_page(kzembed, dkzembed, type);
 }
 
 
@@ -635,6 +635,7 @@ kz_embed_can_go_up (KzEmbed *kzembed)
 
 	/* stupid! */
 	if (strcmp(location, "http://") &&
+	    strcmp(location, "https://")  &&
 	    strcmp(location, "ftp://")  &&
 	    strcmp(location, "file://"))
 		ret = TRUE;
