@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-proxy-menu.c,v 1.2 2004/09/30 00:06:05 ikezoe Exp $
+ *  $Id: kz-proxy-menu.c,v 1.4 2005/02/13 13:20:33 ikezoe Exp $
  */
 
 #include "kz-proxy-menu.h"
@@ -62,7 +62,7 @@ kz_proxy_menu_append_menuitems (GtkMenuShell *shell, KzWindow *kz)
 		g_object_set_data (G_OBJECT (menuitem), KZ_PROXY_MENU_PROXY_KEY,
 				   (gchar*)item->name);
 
-		g_signal_connect (G_OBJECT(menuitem), "activate",
+		g_signal_connect (menuitem, "activate",
 				  G_CALLBACK (cb_proxy_menuitem_activate), kz);
 
 		gtk_menu_shell_append (shell, menuitem);
@@ -82,7 +82,7 @@ kz_proxy_menu_remove_menuitems (GtkMenuShell *shell, KzWindow *kz)
 	for (node = list; node; node = g_list_next(node))
 	{
 		GtkWidget *menuitem = node->data;
-		g_signal_handlers_disconnect_by_func(GTK_OBJECT(menuitem),
+		g_signal_handlers_disconnect_by_func(menuitem,
 						     G_CALLBACK(cb_proxy_menuitem_activate),
 						     kz);
 		gtk_widget_destroy(menuitem);
