@@ -47,6 +47,7 @@ struct _KzTabLabelPrivate
 	gboolean moved;
 	gboolean lock;
 	gboolean auto_refresh;
+	gboolean javascript;
 	guint auto_refresh_id;
 	gulong favicon_signal;
 };
@@ -353,9 +354,10 @@ static void
 kz_tab_label_dispose (GObject *object)
 {
 	KzTabLabel *kztab;
+	KzTabLabelPrivate *priv;
 
 	kztab = KZ_TAB_LABEL(object);
-	KzTabLabelPrivate *priv = KZ_TAB_LABEL_GET_PRIVATE (kztab);
+	priv = KZ_TAB_LABEL_GET_PRIVATE (kztab);
 
 	g_signal_handlers_disconnect_by_func(kz_global_profile,
 					     G_CALLBACK(cb_profile_changed),
@@ -1225,6 +1227,36 @@ kz_tab_label_set_lock (KzTabLabel *kztab, gboolean lock)
 	kz_tab_label_sync_to_profile(kztab);
 }
 
+gboolean
+kz_tab_label_get_javascript (KzTabLabel *kztab)
+{
+	KzTabLabelPrivate *priv;
+
+	g_return_val_if_fail(KZ_IS_TAB_LABEL(kztab), FALSE);
+	priv = KZ_TAB_LABEL_GET_PRIVATE (kztab);
+	return priv->javascript;
+}
+
+
+void
+kz_tab_label_set_javascript (KzTabLabel *kztab, gboolean javascript)
+{
+	KzTabLabelPrivate *priv;
+	gboolean save = FALSE;
+
+	g_return_if_fail(KZ_IS_TAB_LABEL(kztab));
+	priv = KZ_TAB_LABEL_GET_PRIVATE (kztab);
+	priv->javascript = javascript;
+	kz_embed_set_allow_javascript(kztab->kzembed, javascript);
+	kz_actions_set_sensitive(kztab->kz, kztab->kzembed);
+	
+	kz_bookmark_set_javascript(kztab->history, javascript);
+	KZ_CONF_GET("Session", "save", save, BOOL);
+	if (save)
+		kz_bookmark_file_save(KZ_BOOKMARK_FILE(kz_bookmarks->current_session));
+	kz_tab_label_sync_to_profile(kztab);
+}
+
 static gboolean
 cb_auto_refresh(KzTabLabel* kztab)
 {
