@@ -37,7 +37,6 @@ G_BEGIN_DECLS
 
 typedef struct _KzThumbnailsView	KzThumbnailsView;
 typedef struct _KzThumbnailsViewClass	KzThumbnailsViewClass;
-typedef struct _KzThumbnailsViewPriv	KzThumbnailsViewPriv;
 
 typedef enum 
 {
@@ -52,8 +51,6 @@ struct _KzThumbnailsView
 	GtkTable parent;
 
 	KzBookmark *folder;
-
-	KzThumbnailsViewPriv *priv;
 	
 	GList *children;
 };
