@@ -55,6 +55,7 @@
 #include "kz-proxy-menu.h"
 #include "kz-popup-tablist.h"
 #include "kz-ext.h"
+#include "kz-statusbar.h"
 
 extern GtkWidget *kz_moz_embed_new (const gchar *url);
 #ifdef ENABLE_GTK_WEBCORE
@@ -75,13 +76,6 @@ struct _KzWindowPrivate
 {
 	guint       merge_id;
 
-	const char *status_msg;
-	char       *temp_msg;
-
-	/* for find keyword */
-	gboolean    did_find;
-	GtkTooltips *find_tips[2];
-
 	KzEmbedEventMouse *event;
 
 	/* for popup & gesture */
@@ -100,18 +94,9 @@ struct _KzWindowPrivate
 	GList *open_hist;
 	GList *view_hist;
 	GNode *tab_tree;
-
-	/* statusbar id */
-	guint status_link_message;
-	guint status_gesture;
-	guint status_search;
 };
 #define KZ_WINDOW_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), KZ_TYPE_WINDOW, KzWindowPrivate))
 
-#define STATUS_LINK_MESSAGE "INTERNAL_LINK_MESSAGE"
-#define STATUS_GESTURE "INTERNAL_GESTURE"
-#define STATUS_SEARCH "INTERNAL_SEARCH"
-
 enum {
 	TARGET_KAZEHAKASE_TAB,
 	TARGET_NETSCAPE_URL,
@@ -229,17 +214,6 @@ static void     cb_notebook_switch_page_after (GtkNotebook     *notebook,
 					       GtkNotebookPage *page,
 					       guint            page_num,
 					       KzWindow        *kz);
-static void     cb_find_keyword               (GtkWidget       *widget,
-					       KzWindow        *kz);
-static gboolean cb_find_key_release           (GtkWidget       *widget,
-					       GdkEventKey     *event,
-					       KzWindow        *kz);
-#if 0
-static void     cb_find_grab_focus            (GtkWidget       *widget,
-					       KzWindow        *kz);
-#endif
-static void     cb_find_direction_toggle      (GtkToggleButton *button,
-					       KzWindow        *kz);
 static void     cb_gesture_stack_motion       (KzGesture       *gesture,
 					       KzGestureMotion  motion,
 					       KzWindow        *kz);
@@ -443,7 +417,6 @@ kz_window_init (KzWindow *kz)
 {
 	GtkWidget *menu_box;
 	GtkSettings *setting;
-	GtkWidget *vseparator;
 	GList *children, *node;
 	GtkSettings *settings;
 	KzWindowPrivate *priv = KZ_WINDOW_GET_PRIVATE (kz);
@@ -465,13 +438,8 @@ kz_window_init (KzWindow *kz)
 	}
 	g_list_free(children);
 
-	kz->statusbar          = gtk_statusbar_new();
+	kz->statusbar          = kz_statusbar_new(kz);
 	kz->notebook           = gtk_notebook_new();
-	kz->statusbar_area     = gtk_hbox_new(FALSE, 0);
-	kz->find_area          = kz_entry_new_with_stock(GTK_STOCK_FIND, GTK_ICON_SIZE_MENU);
-	kz->find_direction     = gtk_toggle_button_new();
-	kz->dlbox              = kz_download_box_new(kz);
-	kz->grip_box           = gtk_statusbar_new();
 
 	kz->feed_info          = g_object_ref(kz_feed_info_new(kz));
 
@@ -486,10 +454,6 @@ kz_window_init (KzWindow *kz)
 	kz->popup_tablist      = NULL;
 
 	priv->merge_id     = 0;
-	priv->status_msg   = NULL;
-	priv->temp_msg     = NULL;
-
-	priv->did_find     = FALSE;
 
 	priv->event        = NULL;
 
@@ -507,16 +471,6 @@ kz_window_init (KzWindow *kz)
 	priv->view_hist    = NULL;
 	priv->tab_tree     = NULL;
 
-	priv->status_link_message =
-		gtk_statusbar_get_context_id(GTK_STATUSBAR(kz->statusbar),
-					     STATUS_LINK_MESSAGE);
-	priv->status_gesture =
-		gtk_statusbar_get_context_id(GTK_STATUSBAR(kz->statusbar),
-					     STATUS_GESTURE);
-	priv->status_search =
-		gtk_statusbar_get_context_id(GTK_STATUSBAR(kz->statusbar),
-					     STATUS_SEARCH);
-
 	kz->tabs   = kz_bookmark_pure_folder_new();
 	kz->closed_tabs     = kz_bookmark_pure_folder_new();
 	kz->history_search  = kz_bookmark_pure_folder_new();
@@ -676,105 +630,13 @@ kz_window_init (KzWindow *kz)
 		/* curpage = kz_window_open_new_tab(kz, NULL); */
 	}
 
-	/* search area */
-	{
-		gtk_box_pack_start(GTK_BOX(kz->top_vbox), kz->statusbar_area,
-				   FALSE, FALSE, 0);   
-		gtk_widget_show(kz->statusbar_area);
-	}
-
-	/* find direction toggle */
-	{
-		GtkWidget *toggle, *arrow;
-		GtkTooltips *tips = gtk_tooltips_new();
-
-		toggle = kz->find_direction;
-		arrow = gtk_arrow_new(GTK_ARROW_DOWN, GTK_SHADOW_NONE);
-		gtk_container_add(GTK_CONTAINER(toggle), arrow);
-		gtk_box_pack_start(GTK_BOX(kz->statusbar_area), toggle,
-				   FALSE, FALSE, 0); 
-		gtk_widget_show(arrow);
-		gtk_widget_show(toggle);
-
-		kz_entry_set_backtext(KZ_ENTRY(kz->find_area),
-				      _("Find in this page"));
-		g_signal_connect(kz->find_area, "activate",
-				 G_CALLBACK(cb_find_keyword), kz);
-		g_signal_connect(toggle, "toggled",
-				 G_CALLBACK(cb_find_direction_toggle), kz);
-
-		g_object_ref(G_OBJECT(tips));
-		gtk_object_sink(GTK_OBJECT(tips));
-		gtk_tooltips_set_tip(tips, toggle,
-				     _("Find direction"), NULL);
-		priv->find_tips[0] = tips;
-	}
-
-	/* find entry */
-	{
-		GtkTooltips *tips = gtk_tooltips_new();
-
-		gtk_box_pack_start(GTK_BOX(kz->statusbar_area), kz->find_area,
-				   FALSE, FALSE, 0); 
-		g_signal_connect(kz->find_area, 
-				 "key-release-event",
-				 G_CALLBACK(cb_find_key_release), kz);
-		/*
-		g_signal_connect(kz->find_area, 
-				 "grab-focus",
-				 G_CALLBACK(cb_find_grab_focus), kz);
-		*/
-		gtk_widget_show(kz->find_area);
-
-		g_object_ref(G_OBJECT(tips));
-		gtk_object_sink(GTK_OBJECT(tips));
-		gtk_tooltips_set_tip(tips, kz->find_area,
-				     _("Find a word or phrase in this page"), NULL);
-		priv->find_tips[1] = tips;
-	}
-
-	/* grip box */
-	{
-		/* Why 18?
-		   Because gtk_status_bar's max grip width is 18. */
-		gtk_widget_set_size_request(kz->grip_box, 18, -1);
-		gtk_statusbar_set_has_resize_grip(GTK_STATUSBAR(kz->grip_box),
-						  TRUE);
-		gtk_box_pack_end(GTK_BOX(kz->statusbar_area), kz->grip_box,
-				 FALSE, FALSE, 0);
-		gtk_widget_show(kz->grip_box);
-		vseparator = gtk_vseparator_new();
-		gtk_box_pack_end(GTK_BOX(kz->statusbar_area), vseparator,
-				 FALSE, FALSE, 0);
-		gtk_widget_show(vseparator);
-	}
-	
-	/* download box */
-	{
-		gtk_widget_set_size_request(kz->dlbox, 200, -1);
-		gtk_statusbar_set_has_resize_grip(GTK_STATUSBAR(kz->dlbox),
-						  FALSE);
-		gtk_statusbar_push(GTK_STATUSBAR(kz->dlbox), 0,
-				   _("Drop link to download"));
-		gtk_box_pack_end(GTK_BOX(kz->statusbar_area), kz->dlbox,
-				 FALSE, FALSE, 0);
-		gtk_widget_show(kz->dlbox);
-	}
-	
 	/* status bar */
 	{
-		vseparator = gtk_vseparator_new();
-		gtk_statusbar_set_has_resize_grip(GTK_STATUSBAR(kz->statusbar),
-						  FALSE);
-		gtk_box_pack_start(GTK_BOX(kz->statusbar_area), kz->statusbar,
-				   TRUE, TRUE, 0);
+		gtk_box_pack_start(GTK_BOX(kz->top_vbox), kz->statusbar,
+				   FALSE, FALSE, 0);   
 		gtk_widget_show(kz->statusbar);
-		gtk_box_pack_start(GTK_BOX(kz->statusbar_area),
-				   vseparator,
-				   FALSE, FALSE, 0);
-		gtk_widget_show(vseparator);
 	}
-	
+
 	/* from Galeon-1.3.18 */
 	/* initialize the listener for the key theme */
 	settings = gtk_settings_get_default();
@@ -813,7 +675,7 @@ kz_window_remove_tab (KzWindow *kz, GtkWidget *widget)
 }
 
 
-GList *
+const GList *
 kz_window_get_window_list(void)
 {
 	return window_list;
@@ -1605,9 +1467,6 @@ kz_window_destroy (GtkObject *object)
 		g_object_unref(priv->gesture);
 	priv->gesture = NULL;
 
-	g_free(priv->temp_msg);
-        priv->temp_msg = NULL;
-
 	if (priv->event)
 		kz_embed_event_free((KzEmbedEvent *) priv->event);
 	priv->event = NULL;
@@ -1616,13 +1475,6 @@ kz_window_destroy (GtkObject *object)
 		g_object_unref(kz->feed_info);
 	kz->feed_info = NULL;
 
-	if (priv->find_tips[0])
-		g_object_unref(priv->find_tips[0]);
-	priv->find_tips[0] = NULL;
-	if (priv->find_tips[1])
-		g_object_unref(priv->find_tips[1]);
-	priv->find_tips[1] = NULL;
-
 	if (kz->menu_merge)
 		g_object_unref(kz->menu_merge);
 	kz->menu_merge = NULL;
@@ -1805,8 +1657,9 @@ kz_window_store_state (KzWindow *kz)
 	GtkAction *action;
 	gint i, client_x, client_y, width, height;
 	const gchar *label;
-	gboolean active;
+	gboolean active, maximized;
 	KzWindowPrivate *priv;
+	GdkWindowState state;
 
 	g_return_if_fail(KZ_IS_WINDOW(kz));
 	priv = KZ_WINDOW_GET_PRIVATE (kz);
@@ -1816,11 +1669,18 @@ kz_window_store_state (KzWindow *kz)
 	 * window size
 	 */
 
-	gdk_window_get_geometry (GTK_WIDGET(kz)->window,
-				 &client_x, &client_y,
-				 &width, &height, NULL);
-	KZ_CONF_SET("MainWindow", "width",  width,  INT);
-	KZ_CONF_SET("MainWindow", "height", height, INT);
+	state = gdk_window_get_state (GTK_WIDGET(kz)->window);
+	maximized = state & GDK_WINDOW_STATE_MAXIMIZED;
+	KZ_CONF_SET("MainWindow", "maximized", maximized, BOOL);
+
+	if (!maximized)
+	{
+		gdk_window_get_geometry (GTK_WIDGET(kz)->window,
+					 &client_x, &client_y,
+					 &width, &height, NULL);
+		KZ_CONF_SET("MainWindow", "width",  width,  INT);
+		KZ_CONF_SET("MainWindow", "height", height, INT);
+	}
 
 	/*
 	 * sidebar
@@ -1907,7 +1767,7 @@ kz_window_restore_state (KzWindow *kz)
 {
 	GtkAction *action = NULL;
 	gint width = 640, height = 450, sidebar_width = 150;
-	gboolean active = FALSE, bookmarkbar = TRUE;
+	gboolean active = FALSE, bookmarkbar = TRUE, maximized = FALSE;
 	gchar *tab_pos, *label, *sidebar_pos;
 	gint i;
 
@@ -1922,6 +1782,10 @@ kz_window_restore_state (KzWindow *kz)
 
 	gtk_window_set_default_size(GTK_WINDOW(kz), width, height);
 
+	KZ_CONF_GET("MainWindow", "maximized", maximized, BOOL);
+	if (maximized)
+		gtk_window_maximize(GTK_WINDOW(kz));
+
 	/*
 	 * sidebar
 	 */
@@ -2144,15 +2008,9 @@ void
 kz_window_load_url (KzWindow *kz, const gchar *url)
 {
 	GtkWidget *widget = KZ_WINDOW_CURRENT_PAGE(kz);
-	KzTabLabel *kztab = NULL;
 
 	g_return_if_fail(KZ_IS_WINDOW(kz));
 
-	if (widget)
-		kztab = KZ_TAB_LABEL
-			(gtk_notebook_get_tab_label(GTK_NOTEBOOK(kz->notebook),
-						    widget));
-
 	if (gtk_notebook_get_n_pages(GTK_NOTEBOOK(kz->notebook)) < 1 ||
 	    !KZ_IS_EMBED(widget))
 	{
@@ -2213,6 +2071,39 @@ kz_window_get_tree (KzWindow *kz)
 	return priv->tab_tree;
 }
 
+gboolean
+kz_window_activate_action(KzWindow *kz, const gchar *name)
+{
+	GtkAction *action;
+	action = gtk_action_group_get_action(kz->actions, name);
+
+	if (action)
+		gtk_action_activate(action);
+	return action != NULL;
+}
+
+gboolean
+kz_window_activate_popup_action(KzWindow *kz, const gchar *name)
+{
+	GtkAction *action;
+	action = gtk_action_group_get_action(kz->popup_actions, name);
+
+	if (action)
+		gtk_action_activate(action);
+	return action != NULL;
+}
+
+gboolean
+kz_window_activate_tabpop_action(KzWindow *kz, const gchar *name)
+{
+	GtkAction *action;
+	action = gtk_action_group_get_action(kz->tabpop_actions, name);
+
+	if (action)
+		gtk_action_activate(action);
+	return action != NULL;
+}
+
 
 const KzEmbedEventMouse *
 kz_window_get_mouse_event_info (KzWindow *kz)
@@ -2555,162 +2446,12 @@ cb_notebook_switch_page_after (GtkNotebook *notebook, GtkNotebookPage *page,
 }
 
 
-static void
-search_found(GtkWidget* widget, KzWindow *kz)
-{
-	static const GdkColor white = { 0, 0xffff, 0xffff, 0xffff };
-	static const GdkColor black = { 0, 0x0000, 0x0000, 0x0000 };
-
-	g_return_if_fail(KZ_IS_WINDOW(kz));
-
-	if(kz->statusbar) {
-		KzWindowPrivate *priv = KZ_WINDOW_GET_PRIVATE (kz);
-		gtk_statusbar_pop(GTK_STATUSBAR(kz->statusbar),
-				  priv->status_search);
-	}
-
-	gtk_widget_modify_base(widget, GTK_STATE_NORMAL, &white);
-	gtk_widget_modify_text(widget, GTK_STATE_NORMAL, &black);
-}
-
-static void
-search_not_found(GtkWidget* widget, KzWindow *kz)
-{
-	static const GdkColor white = { 0, 0xffff, 0xffff, 0xffff };
-	static const GdkColor red = { 0, 0xffff, 0x6666, 0x6666 };
-	const gchar *search_word;
-	gchar *message;
-
-	g_return_if_fail(KZ_IS_WINDOW(kz));
-
-	search_word = gtk_entry_get_text(GTK_ENTRY(widget));
-	message = g_strdup_printf(_("%s not found"), search_word);
-	if(kz->statusbar) 
-	{
-		KzWindowPrivate *priv = KZ_WINDOW_GET_PRIVATE (kz);
-		gtk_statusbar_pop(GTK_STATUSBAR(kz->statusbar),
-				  priv->status_search);
-		gtk_statusbar_push(GTK_STATUSBAR(kz->statusbar),
-				   priv->status_search,
-				   message);
-	}
-	g_free(message);
-
-	gtk_widget_modify_base(widget, GTK_STATE_NORMAL, &red);
-	gtk_widget_modify_text(widget, GTK_STATE_NORMAL, &white);
-}
-
-static void
-cb_find_keyword (GtkWidget *widget, KzWindow *kz)
-{
-	KzEmbed *embed = KZ_EMBED(KZ_WINDOW_CURRENT_PAGE(kz));
-	GtkToggleButton *toggle = GTK_TOGGLE_BUTTON(kz->find_direction);
-	const gchar *text = gtk_entry_get_text(GTK_ENTRY(widget));
-	gboolean back = gtk_toggle_button_get_active(toggle);
-	KzWindowPrivate *priv = KZ_WINDOW_GET_PRIVATE (kz);
-
-	if (!embed) return;
-
-	if (!text || !(*text))
-	{
-		search_found(widget, kz);
-		return;
-	}
-
-	priv->did_find = kz_embed_find(embed, text, back);
-	if(priv->did_find)
-		search_found(widget, kz);
-	else
-		search_not_found(widget, kz);
-}
-
-static gboolean
-cb_find_key_release (GtkWidget *widget, GdkEventKey *event, KzWindow *kz)
-{
-	KzEmbed *embed ;
-	GtkToggleButton *toggle;
-	const gchar *text;
-	KzWindowPrivate *priv;
-
-	g_return_val_if_fail(KZ_IS_WINDOW(kz), FALSE);
-
-	embed = KZ_EMBED(KZ_WINDOW_CURRENT_PAGE(kz));
-	if (!embed) return FALSE;
-
-	priv = KZ_WINDOW_GET_PRIVATE (kz);
-	toggle = GTK_TOGGLE_BUTTON(kz->find_direction);
-	text = gtk_entry_get_text(GTK_ENTRY(widget));
-	if (!text || !(*text))
-	{
-		search_found(widget,kz);
-		return FALSE;
-	}
-
-	if (event->keyval == GDK_Return || event->keyval == GDK_ISO_Enter)
-	{
-		if (event->state & GDK_SHIFT_MASK)
-		{
-			gboolean back;
-			back = !gtk_toggle_button_get_active(toggle);
-			priv->did_find
-				= kz_embed_find(embed, text, back);
-		}
-	}
-	else
-	{
-		if (!(event->state & GDK_SHIFT_MASK))
-		{
-			gboolean back;
-			back = gtk_toggle_button_get_active(toggle);
-			priv->did_find
-				= kz_embed_incremental_search(embed, text, back);
-		}
-	}
-
-	if(priv->did_find)
-		search_found(widget, kz);
-	else
-		search_not_found(widget, kz);
-	return FALSE;
-}
-
-#if 0
-static void
-cb_find_grab_focus (GtkWidget *widget, KzWindow *kz)
-{
-	KzEmbed *embed ;
-
-	g_return_if_fail(KZ_IS_WINDOW(kz));
-	g_warning("grab");
-}
-#endif
-
-static void
-cb_find_direction_toggle (GtkToggleButton *button, KzWindow *kz)
-{
-	GtkArrow *arrow;
-	gboolean active;
-
-	g_return_if_fail(KZ_IS_WINDOW(kz));
-
-	arrow = GTK_ARROW(GTK_BIN(button)->child);
-	g_return_if_fail(GTK_IS_ARROW(arrow));
-
-	active = gtk_toggle_button_get_active(button);
-	if (active)
-		gtk_arrow_set(arrow, GTK_ARROW_UP, GTK_SHADOW_NONE);
-	else
-		gtk_arrow_set(arrow, GTK_ARROW_DOWN, GTK_SHADOW_NONE);
-}
-
-
 static void
 cb_gesture_stack_motion (KzGesture *gesture, KzGestureMotion motion,
 			 KzWindow *kz)
 {
 	const gchar *label;
 	gchar buf1[256], buf2[256];
-	KzWindowPrivate *priv;
 
 	g_return_if_fail(KZ_IS_WINDOW(kz));
 
@@ -2723,10 +2464,7 @@ cb_gesture_stack_motion (KzGesture *gesture, KzGestureMotion motion,
 		g_snprintf(buf2, G_N_ELEMENTS(buf2),
 			   _("Gesture: %s"), buf1);
 
-	priv = KZ_WINDOW_GET_PRIVATE (kz);
-	gtk_statusbar_pop(GTK_STATUSBAR(kz->statusbar), priv->status_gesture);
-	gtk_statusbar_push(GTK_STATUSBAR(kz->statusbar),
-			   priv->status_gesture, buf2);
+	kz_statusbar_set_gesture_text(KZ_STATUSBAR(kz->statusbar), buf2);
 }
 
 
@@ -2846,11 +2584,7 @@ cb_embed_link_message (KzEmbed *embed, KzWindow *kz)
 	newMessage = kz_embed_get_link_message(KZ_EMBED(embed));
 	if(kz->statusbar) 
 	{
-		KzWindowPrivate *priv = KZ_WINDOW_GET_PRIVATE (kz);
-		gtk_statusbar_pop(GTK_STATUSBAR(kz->statusbar),
-				  priv->status_link_message);
-		gtk_statusbar_push(GTK_STATUSBAR(kz->statusbar),
-				   priv->status_link_message, newMessage);
+		kz_statusbar_set_link_text(KZ_STATUSBAR(kz->statusbar), newMessage);
 	}
 
 	g_free(newMessage);
@@ -2871,11 +2605,36 @@ cb_embed_load_started (KzEmbed *embed, KzWindow *kz)
 static void
 cb_embed_load_finished (KzEmbed *embed, KzWindow *kz)
 {
+	const gchar *uri;
+	gchar *root;
+	gchar *find_uri;
+	gchar *slash_pos;
+
 	g_return_if_fail(KZ_IS_WINDOW(kz));
 
 	kz_actions_set_sensitive(kz, KZ_EMBED(KZ_WINDOW_CURRENT_PAGE(kz)));
 
 	kz_feed_info_change_state(KZ_FEED_INFO(kz->feed_info));
+	
+	uri = kz_embed_get_location(embed);
+	if(!kz_favicon_is_loaded(kz->kzfav, uri))
+	{
+		slash_pos = strstr(uri + strlen("https://"), "/");
+		if(slash_pos)
+		{
+			root = g_strndup(uri, slash_pos - uri);
+			if(root)
+			{
+				find_uri = g_strconcat(root, "/favicon.ico",
+				NULL);
+				kz_favicon_get_icon_from_uri(kz->kzfav, 
+				find_uri, uri);
+
+				g_free(root);
+				g_free(find_uri);
+			}
+		}
+	}
 }
 
 
@@ -2909,8 +2668,7 @@ cb_embed_close_tab (GtkObject *obj, KzWindow *kz)
 	priv->view_hist = g_list_remove(priv->view_hist, kzembed);
 	priv->open_hist = g_list_remove(priv->open_hist, kzembed);
 
-	gtk_statusbar_pop(GTK_STATUSBAR(kz->statusbar),
-			  priv->status_link_message);
+	kz_statusbar_set_link_text(KZ_STATUSBAR(kz->statusbar), NULL);
 
 	node = g_node_find(priv->tab_tree,
 			   G_IN_ORDER, G_TRAVERSE_ALL, kzembed);
@@ -3178,8 +2936,7 @@ cb_embed_dom_mouse_down (KzEmbed *kzembed, KzEmbedEventMouse *event,
 				  GDK_BUTTON_RELEASE_MASK |
 				  GDK_BUTTON_PRESS_MASK,
 				  NULL, cursor, gtk_get_current_event_time ());
-		gtk_statusbar_push(GTK_STATUSBAR(kz->statusbar),
-				   priv->status_gesture, _("Gesture:"));
+		kz_statusbar_set_gesture_text(KZ_STATUSBAR(kz->statusbar), _("Gesture:"));
 		break;
 	}
 	default:
@@ -3265,27 +3022,7 @@ cb_window_motion_notify_event (GtkWidget *widget,
 
 	if (kz_gesture_is_started(priv->gesture))
 	{
-		/* if(state == GDK_BUTTON3_MASK) */
 		kz_gesture_update_position(priv->gesture, x, y);
-		/*
-		else
-		{
-			if (gdk_pointer_is_grabbed ())
-			{
-				gdk_pointer_ungrab (gtk_get_current_event_time ());
-			}
-			kz_gesture_perform(priv->gesture);
-			gtk_statusbar_push(GTK_STATUSBAR(KZ_WINDOW(widget)->statusbar),
-				   priv->status_gesture, "");
-			priv->start_x = 0;
-			priv->start_y = 0;
-			priv->is_gesture = FALSE;
-
-			if (priv->event)
-				kz_embed_event_free((KzEmbedEvent *) priv->event);
-			priv->event = NULL;
-		}
-		*/
 	}
 
 	kz_actions_set_selection_sensitive(kz, kzembed);
@@ -3319,8 +3056,7 @@ cb_window_button_release_event (GtkWidget *widget,
 			kz_gesture_perform(priv->gesture);
 		else
 			kz_gesture_cancel(priv->gesture);
-		gtk_statusbar_pop(GTK_STATUSBAR(KZ_WINDOW(widget)->statusbar),
-				  priv->status_gesture);
+		kz_statusbar_set_gesture_text(KZ_STATUSBAR(kz->statusbar), NULL);
 	}
 
 	if (!priv->is_gesture &&
@@ -3458,8 +3194,7 @@ cb_focus_out_event            (GtkWidget       *widget,
 			{
 				gdk_pointer_ungrab (gtk_get_current_event_time ());
 			}
-			gtk_statusbar_pop(GTK_STATUSBAR(KZ_WINDOW(widget)->statusbar),
-					  priv->status_gesture);
+			kz_statusbar_set_gesture_text(KZ_STATUSBAR(kz->statusbar), NULL);
 		}
 	}
 	return FALSE;
