@@ -63,13 +63,7 @@ struct _KzWindow
 	GtkWidget  *notebook;
 
 	/* bottom of the window */
-	GtkWidget  *statusbar_area;
-
-	GtkWidget  *find_area;
-	GtkWidget  *find_direction;
 	GtkWidget  *statusbar;
-	GtkWidget  *dlbox;
-	GtkWidget  *grip_box;
 
 	/* other objects */
 	GtkActionGroup *actions;
@@ -106,7 +100,7 @@ struct _KzWindowClass
 };
 
 GType	          kz_window_get_type                 (void) G_GNUC_CONST;
-GList            *kz_window_get_window_list          (void);
+const GList      *kz_window_get_window_list          (void);
 GtkWidget        *kz_window_new                      (const gchar *url);
 GtkWidget        *kz_window_get_from_tab             (GtkWidget   *tab_widget);
 GtkWidget        *kz_window_open_new_tab             (KzWindow    *kz,
