@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: GtkNSSDialogs.cpp,v 1.8 2005/04/04 09:02:42 ikezoe Exp $
+ *  $Id: GtkNSSDialogs.cpp,v 1.9 2005/07/20 21:52:36 ikezoe Exp $
  */
 
 /*
@@ -38,7 +38,9 @@
 
 #include <nsCOMPtr.h>
 #include <nsMemory.h>
+#define MOZILLA_INTERNAL_API
 #include <nsIServiceManager.h>
+#undef MOZILLA_INTERNAL_API
 #include <nsIInterfaceRequestor.h>
 #include <nsIInterfaceRequestorUtils.h>
 #include <nsIX509Cert.h>
