@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: MozillaPrivate.cpp,v 1.11 2005/10/24 12:27:05 ikezoe Exp $
+ *  $Id: MozillaPrivate.cpp,v 1.14 2006/09/14 05:25:45 ikezoe Exp $
  */
 
 /*
@@ -26,6 +26,7 @@
 #include "mozilla-config.h"
 
 #include "config.h"
+#include "kazehakase.h"
 
 #include "MozillaPrivate.h"
 
@@ -38,12 +39,17 @@
 #include <nsPromiseFlatString.h>
 #include <nsEscape.h>
 #include <nsIDocument.h>
+#ifdef MOZ_NSICANVASRENDERINGCONTEXTINTERNAL_HAVE_GETINPUTSTREAM_
+#include <nsICanvasRenderingContextInternal.h>
+#include <nsIDOMCanvasRenderingContext2D.h>
+#endif
 #undef MOZILLA_INTERNAL_API
 #include <nsISimpleEnumerator.h>
 #include <nsISupportsPrimitives.h>
 #include <nsIContent.h>
 #include <nsIDOMHTMLDocument.h>
 #include <nsIDOMHTMLElement.h>
+#include <nsIDOMHTMLImageElement.h>
 #include <nsIWidget.h>
 #include <nsPIDOMWindow.h>
 #include <nsIChromeEventHandler.h>
@@ -311,3 +317,79 @@ MozillaPrivate::Unescape(const char *text)
 {
 	return (const char*)nsUnescape((char*)text);
 }
+
+#ifdef MOZ_NSICANVASRENDERINGCONTEXTINTERNAL_HAVE_GETINPUTSTREAM_
+#include "egg-pixbuf-thumbnail.h"
+#define KZ_CANVAS_WIDTH 1024
+#define KZ_CANVAS_HEIGHT 800
+gboolean
+MozillaPrivate::CreateThumbnail(nsIDOMWindow *domWindow, const gchar *uri)
+{
+	nsresult rv;
+	nsCOMPtr<nsIDOMDocument> domDoc;
+	domWindow->GetDocument(getter_AddRefs(domDoc));
+
+	nsCOMPtr<nsICanvasRenderingContextInternal> context;
+
+	nsCString ctxString("@mozilla.org/content/canvas-rendering-context;1?id=2d");
+	context = do_CreateInstance(nsPromiseFlatCString(ctxString).get(), &rv);
+
+	if (NS_FAILED(rv) || !context) return FALSE;
+
+	context->SetDimensions(EGG_PIXBUF_THUMB_LARGE, KZ_THUMB_HEIGHT);
+	context->SetCanvasElement(nsnull);
+
+	nsCOMPtr<nsIDOMCanvasRenderingContext2D> domCanvas = do_QueryInterface(context, &rv);
+	if (NS_FAILED(rv) || !domCanvas) return FALSE;
+
+	float sx, sy;
+	sx = (float) EGG_PIXBUF_THUMB_LARGE / KZ_CANVAS_WIDTH;
+	sy = (float) KZ_THUMB_HEIGHT / KZ_CANVAS_HEIGHT;
+	domCanvas->Scale(sx, sy);
+
+	rv = domCanvas->DrawWindow(domWindow, 0, 0, KZ_CANVAS_WIDTH, KZ_CANVAS_HEIGHT, NS_LITERAL_STRING("rgb(0,0,0)")); 
+	if (NS_FAILED(rv)) return FALSE;
+
+	nsCOMPtr<nsIInputStream> imgStream;
+	rv = context->GetInputStream(NS_LITERAL_CSTRING("image/png"), EmptyString(), getter_AddRefs(imgStream));
+	if (NS_FAILED(rv) || !imgStream) return FALSE;
+
+	// this code wa picked from content/html/content/src/nsHTMLCanvasElement.cpp in firefox-2.0b.
+	PRUint32 bufSize;
+	rv = imgStream->Available(&bufSize);
+	if (NS_FAILED(rv)) return FALSE;
+
+	bufSize += 16;
+	PRUint32 imgSize = 0;
+	char* imgData = (char*)g_malloc((gulong)bufSize);
+	if (!imgData) return FALSE;
+
+	PRUint32 numReadThisTime = 0;
+	while ((rv = imgStream->Read(&imgData[imgSize], bufSize - imgSize,
+					&numReadThisTime)) == NS_OK && numReadThisTime > 0)
+	{
+		imgSize += numReadThisTime;
+		if (imgSize == bufSize)
+		{
+			// need a bigger buffer, just double
+			bufSize *= 2;
+			char* newImgData = (char*)g_realloc(imgData, (gulong)bufSize);
+			if (!newImgData)
+			{
+				g_free(imgData);
+				return FALSE;
+			}
+			imgData = newImgData;
+		}
+	}
+
+	gchar *thumb_filename;
+	thumb_filename = egg_pixbuf_get_thumb_filename(uri, EGG_PIXBUF_THUMB_LARGE);
+	gboolean ret = g_file_set_contents(thumb_filename, imgData, imgSize, NULL);
+		
+	g_free(imgData);
+	g_free(thumb_filename);
+	
+	return ret;
+}
+#endif
