@@ -21,11 +21,15 @@
 
 #include "kz-mozembed.h"
 
+#define KZ_REGRESSION_BUG4474 1
+
 #include <string.h>
 #include <math.h>
 #include <gtkmozembed.h>
 #include <gtkmozembed_internal.h>
 #include <glib/gi18n.h>
+#include <glib/gstdio.h>
+#include <sys/stat.h>
 
 #include "kazehakase.h"
 #include "kz-window.h"
@@ -83,7 +87,6 @@
 #include <nsIWebPageDescriptor.h>
 #include <nsICommandManager.h>
 #include <nsTime.h>
-#include <nsICaret.h>
 #include <nsRect.h>
 #define MOZILLA_STRICT_API
 #include <nsEmbedString.h>
@@ -206,7 +209,8 @@ static gboolean     kz_moz_embed_get_dest_anchors      (KzEmbed      *kzembed,
 							GList       **list);
 
 static void         kz_moz_embed_copy_page             (KzEmbed      *kzembed,
-							KzEmbed      *dkzembed);
+							KzEmbed      *dkzembed,
+							KzEmbedCopyType type);
 static gboolean     kz_moz_embed_shistory_copy         (KzEmbed      *source,
 							KzEmbed      *dest,
 							gboolean      back_history,
@@ -523,9 +527,12 @@ kz_moz_embed_init (KzMozEmbed *kzembed)
 #endif
 	priv->last_highlight = NULL;
 	priv->first_url      = NULL;
+
+#ifndef KZ_REGRESSION_BUG4474
 #ifndef HAVE_GECKO_1_8
 	kz_moz_embed_load_url(KZ_EMBED(kzembed), "about:blank");
 #endif
+#endif
 }
 
 GtkWidget *
@@ -541,7 +548,8 @@ kz_moz_embed_new (const gchar *url)
 	g_moz_embed_set_chrome_mask(GTK_MOZ_EMBED(kzembed->mozembed),
 				    actualChromeMask);
 #endif
-	
+
+#ifndef KZ_REGRESSION_BUG4474
 	// To use the gesture in empty tab, 
 	// After "about:balnk" was loaded, the first url start to load.  
 	if (url)
@@ -549,7 +557,9 @@ kz_moz_embed_new (const gchar *url)
 #ifdef HAVE_GECKO_1_8
 	kz_moz_embed_load_url(KZ_EMBED(kzembed), url);
 #endif
-
+#else
+	kz_moz_embed_load_url(KZ_EMBED(kzembed), url);
+#endif
 	return GTK_WIDGET(kzembed);
 }
 
@@ -918,7 +928,8 @@ kz_moz_embed_location (GtkMozEmbed *embed)
 	KzMozEmbed *kzembed = KZ_MOZ_EMBED(embed);
 
 	g_return_if_fail(KZ_IS_MOZ_EMBED(kzembed));
-	
+
+#ifndef KZ_REGRESSION_BUG4474
 	KzMozEmbedPrivate *priv = KZ_MOZ_EMBED_GET_PRIVATE (kzembed);
 	if (priv->first_url)
 	{
@@ -926,12 +937,12 @@ kz_moz_embed_location (GtkMozEmbed *embed)
 		g_free(priv->first_url);
 		priv->first_url = NULL;
 
-		kz_moz_embed_load_url(KZ_EMBED(kzembed),
-				      tmp);
+		kz_moz_embed_load_url(KZ_EMBED(embed), tmp);
 		g_free(tmp);
 
 		return;
 	}
+#endif
 	if (kzembed->location)
 		g_free(kzembed->location);
 	kzembed->location = gtk_moz_embed_get_location(embed);
@@ -1022,11 +1033,38 @@ net_stop_proccess (KzMozEmbed *kzembed)
 			gchar *filename;
 			filename = mozilla_store_history_file(kzembed);
 			if (filename)
+			{
+				GIOChannel *io;
+				struct stat st;
+				gchar *time;
+				gchar *timestamp_file;
+
+				timestamp_file = g_strconcat(g_get_home_dir(),
+							  HISTORY_DIR,
+							  "timestamp",
+							  NULL);
+
+				g_stat(filename, &st);
+				time = g_strdup_printf("%d", (int)st.st_mtime);
+
+				io = g_io_channel_new_file(timestamp_file, "a+", NULL);
+				g_io_channel_set_encoding(io, NULL, NULL);
+				g_io_channel_write_chars(io, time, strlen(time),
+							 NULL, NULL);
+				g_io_channel_write_chars(io, ",", 1, NULL, NULL);
+				g_io_channel_write_chars(io, filename, strlen(filename),
+							 NULL, NULL);
+				g_io_channel_write_chars(io, "\n", 1, NULL, NULL);
+				g_io_channel_shutdown(io, TRUE, NULL);
+				g_io_channel_unref(io);
 #if USE_HYPERESTRAIER
 				g_idle_add(estsearch_update_index, filename);
 #elif USE_RAST
 				g_idle_add(rast_update_index, filename);
 #endif
+				g_free(timestamp_file);
+				g_free(time);
+			}
 		}
 	}
 	
@@ -2488,7 +2526,8 @@ kz_moz_embed_go_history_index (KzEmbed *kzembed, gint index)
 }
 
 static void
-kz_moz_embed_copy_page (KzEmbed *kzembed, KzEmbed *dkzembed)
+kz_moz_embed_copy_page (KzEmbed *kzembed, KzEmbed *dkzembed,
+			KzEmbedCopyType type)
 {
 	g_return_if_fail(KZ_IS_MOZ_EMBED(kzembed));
 	g_return_if_fail(KZ_IS_MOZ_EMBED(dkzembed));
@@ -2502,8 +2541,16 @@ kz_moz_embed_copy_page (KzEmbed *kzembed, KzEmbed *dkzembed)
         rv = sWrapper->GetPageDescriptor(getter_AddRefs(pageDescriptor));
         if (!pageDescriptor || NS_FAILED(rv)) return;
 
-        rv = dWrapper->LoadDocument(pageDescriptor, 
-				    nsIWebPageDescriptor::DISPLAY_NORMAL);
+	PRUint32 aDisplayType = nsIWebPageDescriptor::DISPLAY_NORMAL;
+	switch (type) {
+	  case KZ_EMBED_COPY_NORMAL:
+	    aDisplayType = nsIWebPageDescriptor::DISPLAY_NORMAL;
+	    break;
+	  case KZ_EMBED_COPY_SOURCE:
+	    aDisplayType = nsIWebPageDescriptor::DISPLAY_AS_SOURCE;
+	    break;
+	}
+        rv = dWrapper->LoadDocument(pageDescriptor, aDisplayType);
 }
 
 
@@ -2857,7 +2904,7 @@ mozilla_store_history_file(KzMozEmbed *kzembed)
 }
 
 
-#if 1 /* FIXME! */
+#ifndef MOZ_NSICANVASRENDERINGCONTEXTINTERNAL_HAVE_GETINPUTSTREAM_
 static KzMozThumbnailCreator *
 kz_window_create_thumbnail_creator (KzWindow *kz)
 {
@@ -2871,7 +2918,7 @@ kz_window_create_thumbnail_creator (KzWindow *kz)
 		gtk_widget_set_size_request(GTK_WIDGET(creator), 0, 0);
 		gtk_widget_show(GTK_WIDGET(creator));
 
-		gtk_box_pack_start(GTK_BOX(kz->statusbar_area),
+		gtk_box_pack_start(GTK_BOX(kz->statusbar),
 				   GTK_WIDGET(creator),
 				   FALSE, FALSE, 0);
 		g_object_set_data(G_OBJECT(kz), 
@@ -2881,16 +2928,24 @@ kz_window_create_thumbnail_creator (KzWindow *kz)
 
 	return creator;
 }
-#endif /* FIXME! */
+#endif
+
 static void
 kz_moz_embed_create_thumbnail (KzEmbed *kzembed)
 {
 	g_return_if_fail(KZ_IS_MOZ_EMBED(kzembed));
 
+	gboolean create_thumbnail = FALSE;
+	KZ_CONF_GET("Global", "create_thumbnail", create_thumbnail, BOOL);
+	if (!create_thumbnail) return;
+
 	KzMozEmbedPrivate *priv = KZ_MOZ_EMBED_GET_PRIVATE (kzembed);
 	KzMozWrapper *wrapper = priv->wrapper;
 	g_return_if_fail (wrapper != NULL);
 
+#ifdef MOZ_NSICANVASRENDERINGCONTEXTINTERNAL_HAVE_GETINPUTSTREAM_
+	wrapper->CreateThumbnail();
+#else
 	nsresult rv;
 	int total, index;
 	rv = wrapper->GetSHInfo (&total, &index);
@@ -2905,14 +2960,10 @@ kz_moz_embed_create_thumbnail (KzEmbed *kzembed)
 
 	KzWindow *kz = KZ_WINDOW(window);
 
-	gboolean create_thumbnail = FALSE;
-	KZ_CONF_GET("Global", "create_thumbnail", create_thumbnail, BOOL);
-	if (create_thumbnail)
-	{
-		KzMozThumbnailCreator *creator;
-		creator = kz_window_create_thumbnail_creator(kz);
-		kz_moz_thumbnail_creator_append_queue(creator, he);
-	}
+	KzMozThumbnailCreator *creator;
+	creator = kz_window_create_thumbnail_creator(kz);
+	kz_moz_thumbnail_creator_append_queue(creator, he);
+#endif
 }
 
 
