@@ -345,21 +345,23 @@ kz_moz_thumbnail_creator_create_thumbnail (KzMozThumbnailCreator *creator, const
 
 	PRBool printing = PR_TRUE;
 
+	KzMozThumbnailProgressListener *aProgress = new KzMozThumbnailProgressListener(ps_name, creator);
+	g_free(ps_name);
+	
 //	print->ExitPrintPreview();
 	/* it is dangerous. */
 	while (printing)
 	{
 		print->GetDoingPrintPreview(&printing);
 		if (!printing)
+		{
+			print->Print(options, aProgress);
 			break;
+		}
 
 		while (gtk_events_pending())
 			gtk_main_iteration();
 	}
-	KzMozThumbnailProgressListener *aProgress = new KzMozThumbnailProgressListener(ps_name, creator);
-	rv = print->Print(options, aProgress);
-
-	g_free(ps_name);
 }
 
 void
