@@ -22,10 +22,12 @@
 #define __KZ_MOZ_UTILS_H__
 
 #include <gtk/gtk.h>
-#include <nsIDOMWindow.h>
-#include <nsIURI.h>
+#define MOZILLA_INTERNAL_API
 #include <nsIComponentManager.h>
 #include <nsIServiceManager.h>
+#undef MOZILLA_INTERNAL_API
+#include <nsIDOMWindow.h>
+#include <nsIURI.h>
 #include <nsIIOService.h>
 #include <nsIInputStream.h>
 #include <nsIOutputStream.h>
@@ -36,7 +38,6 @@
 #include <nsNetCID.h>
 #include <nsCRT.h>
 #include <nsCOMPtr.h>
-#include <nsComponentManagerUtils.h>
 #define MOZILLA_STRICT_API
 #include <nsEmbedString.h>
 #undef MOZILLA_STRICT_API
