@@ -2018,3 +2018,21 @@ KzMozWrapper::ShowPageCertificate (void)
 
 	return certDialogs->ViewCert (NULL, serverCert);
 }
+
+#ifdef MOZ_NSICANVASRENDERINGCONTEXTINTERNAL_HAVE_GETINPUTSTREAM_
+nsresult
+KzMozWrapper::CreateThumbnail (void)
+{
+	nsCOMPtr<nsIDOMWindow> domWindow;
+	GetDOMWindow(getter_AddRefs(domWindow));
+	
+	nsEmbedCString sURI;
+	GetDocumentUrl(sURI);
+	const gchar *uri = sURI.get();
+	
+	if (!MozillaPrivate::CreateThumbnail(domWindow, uri))
+		return NS_ERROR_FAILURE;
+
+	return NS_OK;
+}
+#endif
