@@ -115,6 +115,22 @@ mozilla_prefs_set (void)
 	{
 		g_free(value);
 	}
+
+	// set default charset to ISO-8859-1
+	if (!mozilla_prefs_get_string("intl.charset.default", &value))
+	{
+		mozilla_prefs_set_string("intl.charset.default",
+					 "ISO-8859-1");
+	}
+	else
+	{
+		if (!strcmp(value, "chrome://global-platform/locale/intl.properties"))
+		{
+			mozilla_prefs_set_string("intl.charset.default",
+						 "ISO-8859-1");
+		}
+		g_free(value);
+	}
 	
 	use_proxy_exist = KZ_CONF_GET("Global", "use_proxy", use_proxy, BOOL);
 	
@@ -295,71 +311,6 @@ mozilla_prefs_get_font_list (const char *lang_group,
 			     GList **all_font_list,
 			     char **default_font)
 {
-#if 0
-	nsresult rv;
-
-	nsCOMPtr<nsIFontList> mozFontList;
-	mozFontList = do_CreateInstance("@mozilla.org/gfx/fontlist;1", &rv);
-	if(NS_FAILED(rv)) return FALSE;
-
-	nsCOMPtr<nsISimpleEnumerator> fontEnum;
-	nsEmbedString lang, font;
-	NS_CStringToUTF16(nsEmbedCString(lang_group),
-			  NS_CSTRING_ENCODING_UTF8, lang);
-	NS_CStringToUTF16(nsEmbedCString(font_type),
-			  NS_CSTRING_ENCODING_UTF8, font);
-	mozFontList->AvailableFonts(lang.get(), font.get(),
-				    getter_AddRefs(fontEnum));
-	if(NS_FAILED(rv)) return FALSE;
-
-	if (font_list)
-	{
-		GList *list = NULL;
-		PRBool enumResult;
-
-		for(fontEnum->HasMoreElements(&enumResult) ;
-		    enumResult == PR_TRUE;
-		    fontEnum->HasMoreElements(&enumResult))
-		{
-			nsCOMPtr<nsISupportsString> fontName;
-			fontEnum->GetNext(getter_AddRefs(fontName));
-			if(NS_FAILED(rv)) return FALSE;
-
-			nsEmbedString fontString;
-			fontName->GetData(fontString);
-
-			nsEmbedCString tmp;
-			NS_UTF16ToCString(fontString,
-					  NS_CSTRING_ENCODING_UTF8, tmp);
-			char *gFontString = g_strdup(tmp.get());
-			list = g_list_prepend(list, gFontString);
-		}
-		*font_list = g_list_reverse(list);
-	}
-
-	if (default_font != NULL)
-	{
-		char key[255];
-		char *value = NULL;
-		nsCOMPtr<nsIPrefService> prefService;
-
-	        prefService = do_GetService(NS_PREFSERVICE_CONTRACTID);
-		g_return_val_if_fail(prefService != NULL, FALSE);
-	
-	        nsCOMPtr<nsIPrefBranch> pref;
-	        prefService->GetBranch("", getter_AddRefs(pref));
-		g_return_val_if_fail(pref != NULL, FALSE);
-
-		g_snprintf(key, sizeof(key), "font.name.%s.%s",
-			   font_type, lang_group);
-		
-		pref->GetCharPref(key, &value);
-		*default_font = g_strdup(value);
-		nsMemory::Free(value);
-	}
-#endif
-
-#if 1
 	nsresult rv;
 	PRUint32 count;
 	PRUnichar **fontArray;
@@ -419,17 +370,6 @@ mozilla_prefs_get_font_list (const char *lang_group,
 
 	if (default_font != NULL)
 	{
-#if 0
-		PRUnichar *value;
-		rv = mozFontEnumerator->GetDefaultFont(lang_group,
-						       font_type,
-						       &value);
-		nsEmbedCString tmp;
-		NS_UTF16ToCString(nsEmbedString(value),
-				  NS_CSTRING_ENCODING_UTF8, tmp);
-		*default_font = g_strdup(tmp.get());
-		nsMemory::Free(value);
-#endif		
 		char key[255];
 		char *value = NULL;
 		nsCOMPtr<nsIPrefService> prefService;
@@ -448,7 +388,7 @@ mozilla_prefs_get_font_list (const char *lang_group,
 		*default_font = g_strdup(value);
 		nsMemory::Free(value);
 	}
-#endif
+
 	return TRUE;
 }
 
