@@ -189,7 +189,6 @@ prefs_entry_create (void)
 			 G_CALLBACK(cb_changed), prefsui);
 	gtk_widget_show(check);
 
-#if GTK_CHECK_VERSION(2,6,0)
 	/* inline-completion */
 	check = gtk_check_button_new_with_mnemonic(_("Use _inline-completion in URL entry box"));
 	prefsui->inline_completion = check;
@@ -200,7 +199,7 @@ prefs_entry_create (void)
 	g_signal_connect(check, "toggled",
 			 G_CALLBACK(cb_inline_changed), prefsui);
 	gtk_widget_show(check);
-#endif
+
 	prefsui->changed = FALSE;
 
 	return main_vbox;
@@ -245,14 +244,14 @@ prefs_entry_response (GtkWidget *widget, gint response)
 			(GTK_TOGGLE_BUTTON(prefsui->auto_completion));
 		/* Should change the section name? */
 		KZ_CONF_SET("Global", "use_auto_completion", autocompletion, BOOL);
-#if GTK_CHECK_VERSION(2,6,0)
+
 		/* inline-completion */
 		inline_completion = gtk_toggle_button_get_active
 			(GTK_TOGGLE_BUTTON(prefsui->inline_completion));
 		/* Should change the section name? */
 		KZ_CONF_SET("Global", "use_inline_completion",
 			    inline_completion, BOOL);
-#endif
+
                 prefsui->changed = FALSE;
 
 		break;
