@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: prefs_key_accel.c,v 1.11 2004/09/30 00:06:07 ikezoe Exp $
+ *  $Id: prefs_key_accel.c,v 1.12 2005/02/13 13:20:36 ikezoe Exp $
  */
 
 /*
@@ -375,9 +375,9 @@ accel_key_grab (GtkWidget *button, KzPrefsKeyAccel *self)
 	gtk_window_set_position(GTK_WINDOW(widget),
 				GTK_WIN_POS_CENTER_ON_PARENT);
 	gtk_window_set_default_size(GTK_WINDOW(widget), 300, 50);
-	g_signal_connect(G_OBJECT(widget), "key-press-event",
+	g_signal_connect(widget, "key-press-event",
 			 G_CALLBACK(cb_grab_win_key_press), self);
-	g_signal_connect(G_OBJECT(widget), "key-release-event",
+	g_signal_connect(widget, "key-release-event",
 			 G_CALLBACK(grab_key_value), self);
 
 	gtk_container_set_border_width(GTK_CONTAINER(vbox), 5);
@@ -392,7 +392,7 @@ accel_key_grab (GtkWidget *button, KzPrefsKeyAccel *self)
 
 	but = gtk_button_new_with_label(_("Cancel"));
 	gtk_box_pack_start(GTK_BOX(hbox), but, TRUE, TRUE, 5);
-	g_signal_connect(G_OBJECT(but), "clicked",
+	g_signal_connect(but, "clicked",
 			 G_CALLBACK(cb_cancel_clicked), widget);
 	gtk_widget_show(but);
 
