@@ -21,11 +21,12 @@
 #include "prefs_lang.h"
 
 #include <string.h>
+#include <glib/gi18n.h>
 
 #include "kazehakase.h"
 #include "kz-dlist.h"
 #include "mozilla-prefs.h"
-#include "utils/intl.h"
+#include "gtk-utils.h"
 
 #define DATA_KEY "KzPrefsLang::info"
 
@@ -53,42 +54,6 @@ typedef struct _KzPrefsLang
 	gboolean       enabled_list_updated;
 } KzPrefsLang;
 
-#define CREATE_MENU(menu, array, n_array, field)                               \
-{                                                                              \
-	gint i;                                                                \
-                                                                               \
-	menu = gtk_menu_new ();                                                \
-                                                                               \
-	for (i = 0; i < n_array; i++)                                          \
-	{                                                                      \
-		GtkWidget *item;                                               \
-                                                                               \
-		item = gtk_menu_item_new_with_label (_(array[i].field));       \
-		gtk_menu_shell_append (GTK_MENU_SHELL(menu), item);            \
-		gtk_widget_show (item);                                        \
-	}                                                                      \
-}
-
-
-#define SET_DEFAULT_HISTORY(menu, key, array, n_array, field)                  \
-{                                                                              \
-	gchar *str;                                                            \
-	gint i;                                                                \
-                                                                               \
-	if (mozilla_prefs_get_string(key, &str))                               \
-	{                                                                      \
-		for (i = 0; i < n_array; i++)                                  \
-		{                                                              \
-			if (!strcmp(str, array[i].field))                      \
-			{                                                      \
-				gtk_option_menu_set_history(GTK_OPTION_MENU(menu), i); \
-				break;                                         \
-			}                                                      \
-		}                                                              \
-		g_free(str);                                                   \
-	}                                                                      \
-}
-
 
 static void
 prefs_lang_destroy (gpointer data)
@@ -111,9 +76,9 @@ prefs_lang_create (void)
 {
 	KzPrefsLang *prefsui = g_new0(KzPrefsLang, 1);
 	GtkWidget *main_vbox, *vbox, *hbox;
-	GtkWidget *label, *table, *option_menu, *menu, *frame,*dlist;
+	GtkWidget *label, *table, *option_menu, *frame,*dlist;
 	gchar *str, **langs;
-	gint i;
+	guint i;
 
 	prefsui->enabled_list_updated = FALSE;
 
@@ -157,19 +122,19 @@ prefs_lang_create (void)
 	gtk_container_add(GTK_CONTAINER(frame), hbox);
 	gtk_widget_show(hbox);
 
-	option_menu = gtk_option_menu_new();
+	option_menu = gtk_combo_box_new_text();
 	prefsui->option_menu_lang = option_menu;
 	gtk_label_set_mnemonic_widget(GTK_LABEL(label), option_menu);
 	gtk_box_pack_start(GTK_BOX(hbox), option_menu, FALSE, FALSE, 0);
 	gtk_widget_show(option_menu);
 
-	CREATE_MENU(menu, languages, n_languages, name);
+	GTKUTIL_CREATE_MENU(option_menu, languages, n_languages, name);
 
-	gtk_option_menu_set_menu (GTK_OPTION_MENU(option_menu), menu);
-	SET_DEFAULT_HISTORY(option_menu, "intl.charset.default",
+	mozilla_prefs_get_string("intl.charset.default", &str);
+	GTKUTIL_SET_DEFAULT_HISTORY(option_menu, str,
 			    languages, n_languages, code);
-	gtk_widget_show(menu);
-
+	if (str)
+		g_free(str);
 	/*
 	 *  Auto detect
 	 */
@@ -187,18 +152,23 @@ prefs_lang_create (void)
 	gtk_container_add(GTK_CONTAINER(frame), hbox);
 	gtk_widget_show(hbox);
 
-	option_menu = gtk_option_menu_new();
+	option_menu = gtk_combo_box_new_text();
 	prefsui->option_menu_autodetect = option_menu;
 	gtk_label_set_mnemonic_widget(GTK_LABEL(label), option_menu);
 	gtk_box_pack_start(GTK_BOX(hbox), option_menu, FALSE, FALSE, 0);
 	gtk_widget_show(option_menu);
 
-	CREATE_MENU(menu, encoding_autodetectors, n_encoding_autodetectors, title);
-	gtk_option_menu_set_menu (GTK_OPTION_MENU(option_menu), menu);
-	SET_DEFAULT_HISTORY(option_menu, "intl.charset.detector",
+	GTKUTIL_CREATE_MENU(option_menu, 
+			    encoding_autodetectors,
+			    n_encoding_autodetectors,
+			    title);
+	
+	mozilla_prefs_get_string("intl.charset.detector", &str);
+	GTKUTIL_SET_DEFAULT_HISTORY(option_menu, str,
 			    encoding_autodetectors, n_encoding_autodetectors,
 			    name);
-	gtk_widget_show(menu);
+	if (str)
+		g_free(str);
 
 	/*
 	 *  Accept Language
@@ -225,6 +195,7 @@ prefs_lang_create (void)
 
 	mozilla_prefs_get_string("intl.accept_languages", &str);
 	langs = g_strsplit(str, ",", -1);
+	g_free(str);
 	if (langs)
 	{
 		for (i = 0; langs[i]; i++)
@@ -234,26 +205,22 @@ prefs_lang_create (void)
 		}
 		g_strfreev(langs);
 	}
-	g_signal_connect(G_OBJECT(dlist), "enabled-list-updated",
+	g_signal_connect(dlist, "enabled-list-updated",
 			 G_CALLBACK(cb_enabled_list_updated), prefsui);
 
 	return main_vbox;
 }
 
 
-#define GET_HISTORY(option_menu) \
-	(gtk_option_menu_get_history(GTK_OPTION_MENU(option_menu)))
-
-
 static void
 prefs_lang_apply (KzPrefsLang *prefsui)
 {
-	gint i, j;
+	guint i, j;
 
 	g_return_if_fail(prefsui);
 
-	i = GET_HISTORY(prefsui->option_menu_lang);
-	j = GET_HISTORY(prefsui->option_menu_autodetect);
+	i = gtk_combo_box_get_active(GTK_COMBO_BOX(prefsui->option_menu_lang));
+	j = gtk_combo_box_get_active(GTK_COMBO_BOX(prefsui->option_menu_autodetect));
 	if (i >= 0 && i < n_languages)
 	{
 		mozilla_prefs_set_string("intl.charset.default",
