@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-downloader-sidebar.c,v 1.11 2006/05/16 00:18:52 ikezoe Exp $
+ *  $Id: kz-downloader-sidebar.c,v 1.12 2006/08/25 15:06:38 kous Exp $
  */
 
 #include "kz-downloader-sidebar.h"
@@ -55,13 +55,16 @@ static void     kz_downloader_sidebar_get_property (GObject      *object,
 						   GValue       *value,
 						   GParamSpec   *pspec);
 
+static GtkWidget *kz_downloader_sidebar_new_with_entry (KzSidebarEntry *entry,
+							KzSidebar   *sidebar);
+
 
 static KzSidebarEntry kz_sidebar_downloader = 
 {
 	priority_hint: 0,
 	label:         N_("Downloader"),
 	icon:          NULL,
-	create:        kz_downloader_sidebar_new,
+	create:        kz_downloader_sidebar_new_with_entry,
 };
 
 static GtkVBoxClass *parent_class = NULL;
@@ -385,3 +388,9 @@ kz_downloader_sidebar_new (KzSidebar *sidebar)
 
 	return GTK_WIDGET(dsidebar);
 }
+
+static GtkWidget *
+kz_downloader_sidebar_new_with_entry (KzSidebarEntry *entry, KzSidebar *sidebar)
+{
+	return kz_downloader_sidebar_new (sidebar);
+}
