@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-downloader-sidebar.h,v 1.2 2004/11/25 07:28:48 ikezoe Exp $
+ *  $Id: kz-downloader-sidebar.h,v 1.3 2005/07/09 10:11:49 ikezoe Exp $
  */
 
 #include "kz-sidebar.h"
@@ -36,7 +36,6 @@
 
 typedef struct _KzDownloaderSidebar		KzDownloaderSidebar;
 typedef struct _KzDownloaderSidebarClass	KzDownloaderSidebarClass;
-typedef struct _KzDownloaderSidebarPriv		KzDownloaderSidebarPriv;
 typedef struct _KzDownloaderSidebarItem		KzDownloaderSidebarItem;
 
 struct _KzDownloaderSidebar
@@ -46,8 +45,6 @@ struct _KzDownloaderSidebar
 	KzSidebar         *sidebar;
 	KzDownloaderGroup *downloader_group;
 	GtkWidget         *tree_view;
-
-	KzDownloaderSidebarPriv *priv;
 };
 
 struct _KzDownloaderSidebarClass
