@@ -46,8 +46,8 @@ enum
 };
 
 
-static GtkWidget *kz_tab_list_new (KzSidebar *sidebar);
-static GtkWidget *kz_tab_tree_new (KzSidebar *sidebar);
+static GtkWidget *kz_tab_list_new (KzSidebarEntry *entry, KzSidebar *sidebar);
+static GtkWidget *kz_tab_tree_new (KzSidebarEntry *entry, KzSidebar *sidebar);
 
 
 /* Object class methods */
@@ -451,7 +451,7 @@ kz_tab_tree_get_property (GObject         *object,
 
 
 static GtkWidget *
-kz_tab_list_new (KzSidebar *sidebar)
+kz_tab_list_new (KzSidebarEntry *entry, KzSidebar *sidebar)
 {
 	KzTabTree *tabtree;
 
@@ -465,7 +465,7 @@ kz_tab_list_new (KzSidebar *sidebar)
 
 
 static GtkWidget *
-kz_tab_tree_new (KzSidebar *sidebar)
+kz_tab_tree_new (KzSidebarEntry *entry, KzSidebar *sidebar)
 {
 	KzTabTree *tabtree;
 
