@@ -60,10 +60,12 @@ static void	cb_thumbnail_activate		   (KzThumbnailsView *view,
 						    KzWindow *kz);
 
 static GtkWidget *kz_thumbnails_sidebar_closed_tabs_new 
-						   (KzSidebar *sidebar);
+						   (KzSidebarEntry *entry,
+						    KzSidebar *sidebar);
 #if 0
 static GtkWidget *kz_thumbnails_sidebar_history_search_new 
-						   (KzSidebar *sidebar);
+						   (KzSidebarEntry *entry,
+						    KzSidebar *sidebar);
 #endif
 static KzSidebarEntry kz_sidebar_thumbnails[] = 
 {
@@ -229,7 +231,8 @@ kz_thumbnails_sidebar_get_property (GObject         *object,
 
 
 static GtkWidget *
-kz_thumbnails_sidebar_closed_tabs_new (KzSidebar *sidebar)
+kz_thumbnails_sidebar_closed_tabs_new (KzSidebarEntry *entry,
+				       KzSidebar *sidebar)
 {
 	KzThumbnailsSidebar *tsidebar;
 	KzBookmark *proxy;
@@ -253,7 +256,8 @@ kz_thumbnails_sidebar_closed_tabs_new (KzSidebar *sidebar)
 
 #if 0
 static GtkWidget *
-kz_thumbnails_sidebar_history_search_new (KzSidebar *sidebar)
+kz_thumbnails_sidebar_history_search_new (KzSidebarEntry *entry,
+					  KzSidebar *sidebar)
 {
 	KzThumbnailsSidebar *tsidebar;
 
