@@ -24,6 +24,7 @@
 #include <sys/types.h>
 #include <unistd.h>
 #include <glib/gstdio.h>
+#include <stdlib.h>
 
 #include "utils.h"
 #include "glib-utils.h"
@@ -494,6 +495,63 @@ purge_history_file(const gchar *path, time_t limit_seconds)
 	g_dir_close(gdir);
 }
 
+void
+purge_history_file_by_timestamp(const gchar *timestamp_path, time_t limit_seconds)
+{
+	gchar buf[BUFFER_SIZE];
+	gchar *tmp_file;
+	gint fd;
+	gint i;
+	FILE *fp;
+	GTimeVal now;
+	time_t t;
+
+	g_get_current_time(&now);
+	t = now.tv_sec;
+
+	fd = g_file_open_tmp("kzXXXXXX", &tmp_file, NULL);
+
+	fp = g_fopen(timestamp_path, "a+");
+	if(fp)
+	{
+		while(fgets(buf, sizeof(buf), fp))
+		{
+			gchar *pos;
+			gchar *time , *path;
+			gint time_int;
+			struct stat st;
+
+			pos = g_strrstr(buf, ",");
+			time = g_strndup(buf, pos - buf);
+			path = g_strdup(pos+1);
+
+			for(i = 0;i <= strlen(path);i++)
+				if(path[i] == '\n')
+					path[i] = '\0';
+
+			time_int = atoi(time);
+
+			if(t - time_int > limit_seconds)
+			{
+				if (g_stat(path, &st) == 0 &&
+						t - st.st_mtime > limit_seconds)
+				{
+					/* remove file over storege period */
+					g_unlink(path);
+					g_free(time);
+					g_free(path);
+					continue;
+				}
+			}
+
+			write(fd, buf, strlen(buf));
+
+			g_free(time);
+			g_free(path);
+		}
+	}
+}
+
 gchar *
 ensure_encode_string(const gchar *text, 
 		     const gchar *encode,
@@ -589,6 +647,7 @@ typedef struct _KzPixbufConverter
 } KzPixbufConverter;
 
 
+#ifndef MOZ_NSICANVASRENDERINGCONTEXTINTERNAL_HAVE_GETINPUTSTREAM_
 static gboolean
 idle_dispose_converter(gpointer data)
 {
@@ -640,7 +699,7 @@ cb_io_in(GIOChannel *iochannel, GIOCondition condition,
 		
 			/* scale */
 			scale = gdk_pixbuf_scale_simple(pixbuf, 
-						        200, 256,
+						        KZ_THUMB_HEIGHT, EGG_PIXBUF_THUMB_LARGE,
 						        GDK_INTERP_HYPER);
 		
 			/* rotate image */
@@ -729,6 +788,7 @@ convert_image (const gchar *ps_file, const gchar *png_file)
 		       G_IO_IN | G_IO_PRI | G_IO_ERR | G_IO_HUP,
 		       cb_io_in, converter);
 }
+#endif
 
 gboolean
 str_isdigit (const gchar *str)
