@@ -40,6 +40,7 @@ enum {
 	PROP_0,
 	PROP_BACKTEXT,
 	PROP_STOCK,
+	PROP_STOCK_SIZE,
 	PROP_PIXBUF
 };
 
@@ -137,11 +138,19 @@ kz_entry_class_init (KzEntryClass *klass)
 							      G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (gobject_class,
 					 PROP_STOCK,
-					 g_param_spec_string ("stock",
+					 g_param_spec_string ("stock-id",
 							      _("Stock ID"),
-							      _("Stock ID for a icon"),
+							      _("Stock ID for an icon"),
 							      NULL,
 							      G_PARAM_READWRITE));
+	g_object_class_install_property (gobject_class,
+					 PROP_STOCK_SIZE,
+					 g_param_spec_int ("stock-size",
+							   _("Stock Icon size"),
+							   _("The size of the icon"),
+							   0, G_MAXINT,
+							   GTK_ICON_SIZE_MENU,
+							   G_PARAM_READWRITE));
 	g_object_class_install_property (gobject_class,
 					 PROP_PIXBUF,
 					 g_param_spec_object ("pixbuf",
@@ -207,6 +216,11 @@ kz_entry_set_property (GObject *object,
 					      g_value_get_object (value));
 		break;
 	 case PROP_STOCK:
+		entry->stock_id = g_value_dup_string (value);
+		entry->icon_type = KZ_ENTRY_ICON_STOCK;
+		break;
+	 case PROP_STOCK_SIZE:
+		entry->icon_size = g_value_get_int (value);
 		break;
 	 default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
@@ -232,7 +246,12 @@ kz_entry_get_property (GObject *object,
 		g_value_set_object (value,
 				    (GObject*) entry->pixbuf);
 		break;
-	default:
+	 case PROP_STOCK:
+		g_value_set_string (value, entry->stock_id);
+		break;
+	 case PROP_STOCK_SIZE:
+		g_value_set_int (value, entry->icon_size);
+	 default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
 		break;
 	}
@@ -375,11 +394,14 @@ kz_entry_new (void)
 
 
 GtkWidget *
-kz_entry_new_with_stock (const gchar *stock_id)
+kz_entry_new_with_stock (const gchar *stock_id, GtkIconSize size)
 {
 	KzEntry *kzentry;
 
-	kzentry = g_object_new (KZ_TYPE_ENTRY, NULL);
+	kzentry = g_object_new (KZ_TYPE_ENTRY,
+				"stock-id", stock_id,
+				"stock-size", size,
+				NULL);
 
 	return GTK_WIDGET (kzentry);
 }
@@ -1612,7 +1634,7 @@ kz_entry_set_icon_from_stock (KzEntry  *entry,
 	if (entry->with_arrow)
 		entry->icon_width += ARROW_WIDTH;
 
-	g_object_notify(G_OBJECT (entry), "stock");
+	g_object_notify(G_OBJECT (entry), "stock-id");
   
 	g_object_thaw_notify (G_OBJECT (entry));
 }
