@@ -72,7 +72,7 @@ struct _KzEntryClass
 
 GType      kz_entry_get_type                (void) G_GNUC_CONST;
 GtkWidget *kz_entry_new                     (void);
-GtkWidget *kz_entry_new_with_stock          (const gchar *stock_id);
+GtkWidget *kz_entry_new_with_stock          (const gchar *stock_id, GtkIconSize size);
 
 void       kz_entry_set_arrow               (KzEntry      *entry,
 					     gboolean     arrow);
